@@ -11,9 +11,6 @@ These docstrings contain reference documentation; for tutorials, explanations,
 or how-to documentation, please see other sections of the online documentation.
 """
 
-import logging
-import os
-
 import astropy
 import astropy.constants as c
 import astropy.time as time
@@ -22,11 +19,11 @@ import numpy as np
 import pkg_resources
 from astropy.units import si
 
+from pint import logging
 from pint.extern._version import get_versions
 from pint.pulsar_ecliptic import PulsarEcliptic
 from pint.pulsar_mjd import PulsarMJD, time_to_longdouble  # ensure always loaded
 
-log = logging.getLogger(__name__)
 
 __all__ = [
     "__version__",
@@ -61,7 +58,7 @@ __version__ = get_versions()["version"]
 ls = u.def_unit("ls", c.c * 1.0 * u.s)
 
 # DM unit (pc cm^-3)
-dmu = u.def_unit("dmu", u.pc * u.cm ** -3)
+dmu = u.def_unit("dmu", u.pc * u.cm**-3)
 
 # define equivalency for astropy units
 light_second_equivalency = [(ls, si.second, lambda x: x, lambda x: x)]
@@ -70,10 +67,10 @@ hourangle_second = u.def_unit("hourangle_second", u.hourangle / np.longdouble(36
 
 # Following are from here:
 # http://ssd.jpl.nasa.gov/?constants (grabbed on 30 Dec 2013)
-GMsun = 1.32712440018e20 * u.m ** 3 / u.s ** 2
+GMsun = 1.32712440018e20 * u.m**3 / u.s**2
 
 # Solar mass in time units (sec)
-Tsun = (GMsun / c.c ** 3).to(u.s)
+Tsun = (GMsun / c.c**3).to(u.s)
 
 # Planet system(!) masses in time units
 Tmercury = Tsun / 6023600.0
@@ -105,8 +102,6 @@ pint_units = {
 import astropy.version
 
 if astropy.version.major < 4:
-    log.warning(
-        "Using astropy version {}. To get most recent IERS data, upgrade to astropy >= 4.0".format(
-            astropy.__version__
-        )
+    raise ValueError(
+        f"astropy version must be >=4 (currently it is {astropy.version.major})"
     )
