@@ -101,7 +101,7 @@ def sig2sigma(sig, two_tailed=True, logprob=False):
     results[mask] = norm.isf(sig[mask] * 0.5)
     mask = ~mask
     if logprob:
-        x0 = (-2 * (logsig[mask] + np.log(np.pi ** 0.5))) ** 0.5
+        x0 = (-2 * (logsig[mask] + np.log(np.pi**0.5))) ** 0.5
     else:
         x0 = (-2 * np.log(sig[mask] * (np.pi) ** 0.5)) ** 0.5
     results[mask] = x0 - np.log(x0) / (1 + 2 * x0)
@@ -111,21 +111,21 @@ def sig2sigma(sig, two_tailed=True, logprob=False):
 
 def sigma2sig(sigma, two_tailed=True):
     """Convert "sigma" units to chance probability, i.e., return the integral
-       of the normal distribution from sigma to infinity, or twice that
-       quantity if two_tailed.
-       args
-       ----
-       sigma   argument for the normal distribution
+    of the normal distribution from sigma to infinity, or twice that
+    quantity if two_tailed.
+    args
+    ----
+    sigma   argument for the normal distribution
 
-       kwargs
-       ------
-       two_tailed [True] if True, return twice the integral, else once
+    kwargs
+    ------
+    two_tailed [True] if True, return twice the integral, else once
     """
     # this appears to handle up to machine precision with no problem
 
     if two_tailed:
-        return erfc(sigma / 2 ** 0.5)
-    return 1 - 0.5 * erfc(-sigma / 2 ** 0.5)
+        return erfc(sigma / 2**0.5)
+    return 1 - 0.5 * erfc(-sigma / 2**0.5)
 
 
 def sigma_trials(sigma, trials):
@@ -137,12 +137,12 @@ def sigma_trials(sigma, trials):
         return sig2sigma(p)
     else:
         # use an asymptotic expansion -- this needs to be checked!
-        return (sigma ** 2 - 2 * np.log(trials)) ** 0.5
+        return (sigma**2 - 2 * np.log(trials)) ** 0.5
 
 
 def z2m(phases, m=2):
-    """ Return the Z^2_m test for each harmonic up to the specified m.
-        See de Jager et al. 1989 for definition.
+    """Return the Z^2_m test for each harmonic up to the specified m.
+    See de Jager et al. 1989 for definition.
     """
 
     phases = np.asarray(phases) * TWOPI  # phase in radians
@@ -166,28 +166,27 @@ def z2m(phases, m=2):
 
 
 def z2mw(phases, weights, m=2):
-    """ Return the Z^2_m test for each harmonic up to the specified m.
+    """Return the Z^2_m test for each harmonic up to the specified m.
 
-        The user provides a list of weights.  In the case that they are
-        well-distributed or assumed to be fixed, the CLT applies and the
-        statistic remains calibrated.  Nice!
-     """
+    The user provides a list of weights.  In the case that they are
+    well-distributed or assumed to be fixed, the CLT applies and the
+    statistic remains calibrated.  Nice!
+    """
 
     phases = np.asarray(phases) * (2 * np.pi)  # phase in radians
 
     s = (
-        (np.asarray([(np.cos(k * phases) * weights).sum() for k in range(1, m + 1)]))
-        ** 2
-        + (np.asarray([(np.sin(k * phases) * weights).sum() for k in range(1, m + 1)]))
-        ** 2
-    )
+        np.asarray([(np.cos(k * phases) * weights).sum() for k in range(1, m + 1)])
+    ) ** 2 + (
+        np.asarray([(np.sin(k * phases) * weights).sum() for k in range(1, m + 1)])
+    ) ** 2
 
-    return np.cumsum(s) * (2.0 / (weights ** 2).sum())
+    return np.cumsum(s) * (2.0 / (weights**2).sum())
 
 
 def cosm(phases, m=2):
-    """ Return the cosine test for each harmonic up to the specified m.
-        See de Jager et al. 1994 for definition
+    """Return the cosine test for each harmonic up to the specified m.
+    See de Jager et al. 1994 for definition
     """
 
     phases = np.asarray(phases) * TWOPI  # phase in radians
@@ -202,12 +201,12 @@ def cosm(phases, m=2):
 
 
 def sf_z2m(ts, m=2):
-    """ Return the survival function (chance probability) according to the
-        asymptotic calibration for the Z^2_m test.
+    """Return the survival function (chance probability) according to the
+    asymptotic calibration for the Z^2_m test.
 
-        args
-        ----
-        ts      result of the Z^2_m test
+    args
+    ----
+    ts      result of the Z^2_m test
     """
 
     return chi2.sf(ts, 2 * m)
@@ -219,8 +218,8 @@ def best_m(phases, weights=None, m=100):
 
 
 def em_four(phases, m=2, weights=None):
-    """ Return the empirical Fourier coefficients up to the mth harmonic.
-        These are derived from the empirical trignometric moments."""
+    """Return the empirical Fourier coefficients up to the mth harmonic.
+    These are derived from the empirical trignometric moments."""
 
     phases = np.asarray(phases) * TWOPI  # phase in radians
 
@@ -238,8 +237,8 @@ def em_four(phases, m=2, weights=None):
 
 
 def em_lc(coeffs, dom):
-    """ Evaluate the light curve at the provided phases (0 to 1) for the
-        provided coeffs, e.g., as estimated by em_four."""
+    """Evaluate the light curve at the provided phases (0 to 1) for the
+    provided coeffs, e.g., as estimated by em_four."""
 
     dom = np.asarray(dom) * (2 * np.pi)
 
@@ -251,10 +250,10 @@ def em_lc(coeffs, dom):
 
 
 def hm(phases, m=20, c=4):
-    """ Calculate the H statistic (de Jager et al. 1989) for given phases.
-        H_m = max(Z^2_k - c*(k-1)), 1 <= k <= m
-        m == maximum search harmonic
-        c == offset for each successive harmonic
+    """Calculate the H statistic (de Jager et al. 1989) for given phases.
+    H_m = max(Z^2_k - c*(k-1)), 1 <= k <= m
+    m == maximum search harmonic
+    c == offset for each successive harmonic
     """
     phases = np.asarray(phases) * (2 * np.pi)  # phase in radians
 
@@ -266,21 +265,20 @@ def hm(phases, m=20, c=4):
 
 
 def hmw(phases, weights, m=20, c=4):
-    """ Calculate the H statistic (de Jager et al. 1989) and weight each
-        sine/cosine with the weights in the argument.  The distribution
-        is corrected such that the CLT still applies, i.e., it maintains
-        the same calibration as the unweighted version."""
+    """Calculate the H statistic (de Jager et al. 1989) and weight each
+    sine/cosine with the weights in the argument.  The distribution
+    is corrected such that the CLT still applies, i.e., it maintains
+    the same calibration as the unweighted version."""
 
     phases = np.asarray(phases) * (2 * np.pi)  # phase in radians
 
     s = (
-        (np.asarray([(weights * np.cos(k * phases)).sum() for k in range(1, m + 1)]))
-        ** 2
-        + (np.asarray([(weights * np.sin(k * phases)).sum() for k in range(1, m + 1)]))
-        ** 2
-    )
+        np.asarray([(weights * np.cos(k * phases)).sum() for k in range(1, m + 1)])
+    ) ** 2 + (
+        np.asarray([(weights * np.sin(k * phases)).sum() for k in range(1, m + 1)])
+    ) ** 2
 
-    return ((2.0 / (weights ** 2).sum()) * np.cumsum(s) - c * np.arange(0, m)).max()
+    return ((2.0 / (weights**2).sum()) * np.cumsum(s) - c * np.arange(0, m)).max()
 
 
 # @vec
@@ -324,19 +322,19 @@ def sf_hm(h, m=20, c=4, logprob=False):
 
 
 def h2sig(h):
-    """ Shortcut function for calculating sigma from the H-test."""
+    """Shortcut function for calculating sigma from the H-test."""
     return sig2sigma(sf_hm(h, logprob=True), logprob=True)
 
 
 @vec
 def sf_h20_dj1989(h):
     """Convert the H-test statistic to a chance probability according to the
-       formula of de Jager et al. 1989 -- NB the quadratic term is NOT correct."""
+    formula of de Jager et al. 1989 -- NB the quadratic term is NOT correct."""
     if h <= 23:
         return 0.9999755 * np.exp(-0.39802 * h)
     if h > 50:
         return 4e-8
-    return 1.210597 * np.exp(-0.45901 * h + 0.0022900 * h ** 2)
+    return 1.210597 * np.exp(-0.45901 * h + 0.0022900 * h**2)
 
 
 def sf_h20_dj2010(h):
@@ -350,14 +348,14 @@ def sig2h20(sig):
 
 
 def sf_stackedh(k, h, l=0.398405):
-    """ Return the chance probability for a stacked H test assuming the
-        null df for H is exponentially distributed with scale l and that
-        there are k sub-integrations yielding a total TS of h.  See, e.g.
-        de Jager & Busching 2010."""
+    """Return the chance probability for a stacked H test assuming the
+    null df for H is exponentially distributed with scale l and that
+    there are k sub-integrations yielding a total TS of h.  See, e.g.
+    de Jager & Busching 2010."""
 
     fact = lambda x: gamma(x + 1)
     p = 0
     c = l * h
     for i in range(k):
-        p += c ** i / fact(i)
+        p += c**i / fact(i)
     return p * np.exp(-c)
