@@ -1,14 +1,11 @@
 """Timing model absolute phase (TZRMJD, TZRSITE ...)"""
-import logging
-
 import astropy.units as u
+from loguru import logger as log
 
 import pint.toa as toa
 from pint.models.parameter import MJDParameter, floatParameter, strParameter
 from pint.models.timing_model import MissingParameter, PhaseComponent
 
-log = logging.getLogger(__name__)
-
 
 class AbsPhase(PhaseComponent):
     """Absolute phase model.
@@ -22,7 +19,7 @@ class AbsPhase(PhaseComponent):
 
     Note
     ----
-    Although this class is condisder as a phase component, it does not
+    Although this class is considered as a phase component, it does not
     provide the phase_func
     """
 
@@ -30,7 +27,7 @@ class AbsPhase(PhaseComponent):
     category = "absolute_phase"
 
     def __init__(self):
-        super(AbsPhase, self).__init__()
+        super().__init__()
         self.add_param(
             MJDParameter(
                 name="TZRMJD", description="Epoch of the zero phase.", time_scale="utc"
@@ -45,16 +42,16 @@ class AbsPhase(PhaseComponent):
             floatParameter(
                 name="TZRFRQ",
                 units=u.MHz,
-                description="The frequency of the zero phase mearsured.",
+                description="The frequency of the zero phase measured.",
             )
         )
         self.tz_cache = None
 
     def setup(self):
-        super(AbsPhase, self).setup()
+        super().setup()
 
     def validate(self):
-        super(AbsPhase, self).validate()
+        super().validate()
         # Make sure the cached TOA is cleared
         self.tz_cache = None
         # Check input Parameters
@@ -80,7 +77,7 @@ class AbsPhase(PhaseComponent):
         We are treating the TZRMJD as a special TOA.
         Note that any observatory clock corrections will be applied
         to this TOA, as with any other TOA. This does not affect the
-        value of the TZRMJD parmeter, however.
+        value of the TZRMJD parameter, however.
         """
         clkc_info = toas.clock_corr_info
         # If we have cached the TZR TOA and all the TZR* and clock info has not changed, then don't rebuild it
@@ -97,6 +94,7 @@ class AbsPhase(PhaseComponent):
         # Otherwise we have to build the TOA and apply clock corrections
         # NOTE: Using TZRMJD.quantity.jd[1,2] so that the time scale can be properly
         # set to the TZRSITE default timescale (e.g. UTC for TopoObs and TDB for SSB)
+        log.debug("Creating and dealing with the single TZR_toa for absolute phase")
         TZR_toa = toa.TOA(
             (self.TZRMJD.quantity.jd1 - 2400000.5, self.TZRMJD.quantity.jd2),
             obs=self.TZRSITE.value,
@@ -109,6 +107,7 @@ class AbsPhase(PhaseComponent):
             ephem=toas.ephem,
             planets=toas.planets,
         )
+        log.debug("Done with TZR_toa")
         self.tz_cache = tz
         self.tz_hash = hash((self.TZRMJD.value, self.TZRSITE.value, self.TZRFRQ.value))
         self.tz_clkc_info = clkc_info
@@ -117,7 +116,7 @@ class AbsPhase(PhaseComponent):
         return tz
 
     def make_TZR_toa(self, toas):
-        """ Calculate the TZRMJD if one not given.
+        """Calculate the TZRMJD if one not given.
 
         TZRMJD = first toa after PEPOCH.
         """
