@@ -1,7 +1,7 @@
 """Astrometric models for describing pulsar sky positions."""
 import copy
-import logging
 import sys
+import warnings
 
 import astropy.constants as const
 import astropy.coordinates as coords
@@ -9,6 +9,13 @@ import astropy.units as u
 import numpy as np
 from astropy.time import Time
 
+from loguru import logger as log
+
+try:
+    from erfa import ErfaWarning
+except ImportError:
+    from astropy._erfa import ErfaWarning
+
 from pint import ls
 from pint.models.parameter import (
     AngleParameter,
@@ -20,7 +27,6 @@ from pint.models.timing_model import DelayComponent, MissingParameter
 from pint.pulsar_ecliptic import OBL, PulsarEcliptic
 from pint.utils import add_dummy_distance, remove_dummy_distance
 
-log = logging.getLogger(__name__)
 
 astropy_version = sys.modules["astropy"].__version__
 mas_yr = u.mas / u.yr
@@ -63,13 +69,19 @@ class Astrometry(DelayComponent):
         # TODO: would it be better for this to return a 6-vector (pos, vel)?
         return self.coords_as_ICRS(epoch=epoch).cartesian.xyz.transpose()
 
-    def ssb_to_psb_xyz_ECL(self, epoch=None):
+    def ssb_to_psb_xyz_ECL(self, epoch=None, ecl=None):
         """Returns unit vector(s) from SSB to pulsar system barycenter under Ecliptic coordinates.
 
         If epochs (MJD) are given, proper motion is included in the calculation.
+
+        Parameters
+        ----------
+        epoch : float, optional
+        ecl : str, optional
+            Obliquity (IERS2010 by default)
         """
         # TODO: would it be better for this to return a 6-vector (pos, vel)?
-        return self.coords_as_ECL(epoch=epoch).cartesian.xyz.transpose()
+        return self.coords_as_ECL(epoch=epoch, ecl=ecl).cartesian.xyz.transpose()
 
     def sun_angle(self, toas, heliocenter=True, also_distance=False):
         """Compute the pulsar-observatory-Sun angle.
@@ -102,7 +114,7 @@ class Astrometry(DelayComponent):
         else:
             osv = -tbl["ssb_obs_pos"].quantity.copy()
         psr_vec = self.ssb_to_psb_xyz_ICRS(epoch=tbl["tdbld"])
-        r = (osv ** 2).sum(axis=1) ** 0.5
+        r = (osv**2).sum(axis=1) ** 0.5
         osv /= r[:, None]
         cos = (osv * psr_vec).sum(axis=1)
         if also_distance:
@@ -136,7 +148,7 @@ class Astrometry(DelayComponent):
                     * tbl["ssb_obs_pos"].unit ** 2
                 )
                 delay[c] += (
-                    (0.5 * (re_sqr / L) * (1.0 - re_dot_L ** 2 / re_sqr)).to(ls).value
+                    (0.5 * (re_sqr / L) * (1.0 - re_dot_L**2 / re_sqr)).to(ls).value
                 )
         return delay * u.second
 
@@ -158,7 +170,7 @@ class Astrometry(DelayComponent):
         ssb_psr = self.ssb_to_psb_xyz_ICRS(epoch=np.array(rd["epoch"]))
 
         # Cartesian coordinates, and derived quantities
-        rd["ssb_obs_r"] = np.sqrt(np.sum(ssb_obs ** 2, axis=1))
+        rd["ssb_obs_r"] = np.sqrt(np.sum(ssb_obs**2, axis=1))
         rd["ssb_obs_z"] = ssb_obs[:, 2]
         rd["ssb_obs_xy"] = np.sqrt(ssb_obs[:, 0] ** 2 + ssb_obs[:, 1] ** 2)
         rd["ssb_obs_x"] = ssb_obs[:, 0]
@@ -202,7 +214,7 @@ class Astrometry(DelayComponent):
         rd = self.get_d_delay_quantities(toas)
 
         px_r = np.sqrt(rd["ssb_obs_r"] ** 2 - rd["in_psr_obs"] ** 2)
-        dd_dpx = 0.5 * (px_r ** 2 / (u.AU * const.c)) * (u.mas / u.radian)
+        dd_dpx = 0.5 * (px_r**2 / (u.AU * const.c)) * (u.mas / u.radian)
 
         # We want to return sec / mas
         return dd_dpx.decompose(u.si.bases) / u.mas
@@ -350,9 +362,14 @@ class AstrometryEquatorial(Astrometry):
             else:
                 newepoch = Time(epoch, scale="tdb", format="mjd")
             position_now = add_dummy_distance(self.get_psr_coords())
-            position_then = remove_dummy_distance(
-                position_now.apply_space_motion(new_obstime=newepoch)
-            )
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore", ErfaWarning)
+                # for the most part the dummy distance should remove any potential erfa warnings
+                # but for some very large proper motions that does not quite work
+                # so we catch the warnings
+                position_then = position_now.apply_space_motion(new_obstime=newepoch)
+                position_then = remove_dummy_distance(position_then)
+
             return position_then
 
     def coords_as_ICRS(self, epoch=None):
@@ -1011,8 +1028,8 @@ class AstrometryEcliptic(Astrometry):
             frame=PulsarEcliptic,
         )
         c_ICRS = c.transform_to(coords.ICRS)
-        m_eq.RAJ.uncertainty = c_ICRS.pm_ra_cosdec * dt / np.cos(c_ICRS.dec)
-        m_eq.DECJ.uncertainty = c_ICRS.pm_dec * dt
+        m_eq.RAJ.uncertainty = np.abs(c_ICRS.pm_ra_cosdec * dt / np.cos(c_ICRS.dec))
+        m_eq.DECJ.uncertainty = np.abs(c_ICRS.pm_dec * dt)
         # use fake proper motions to convert uncertainties on proper motion
         # assume that PMELONG uncertainty includes cos(DEC)
         c = coords.SkyCoord(
@@ -1025,8 +1042,8 @@ class AstrometryEcliptic(Astrometry):
             frame=PulsarEcliptic,
         )
         c_ICRS = c.transform_to(coords.ICRS)
-        m_eq.PMRA.uncertainty = c_ICRS.pm_ra_cosdec
-        m_eq.PMDEC.uncertainty = c_ICRS.pm_dec
+        m_eq.PMRA.uncertainty = np.abs(c_ICRS.pm_ra_cosdec)
+        m_eq.PMDEC.uncertainty = np.abs(c_ICRS.pm_dec)
         # freeze comparable parameters
         m_eq.RAJ.frozen = self.ELONG.frozen
         m_eq.DECJ.frozen = self.ELAT.frozen
