@@ -2,7 +2,6 @@
 from pint.models.parameter import floatParameter
 from pint.models.pulsar_binary import PulsarBinary
 from pint.models.stand_alone_psr_binaries.DD_model import DDmodel
-from pint.models.timing_model import MissingParameter
 
 
 class BinaryDD(PulsarBinary):
@@ -26,8 +25,10 @@ class BinaryDD(PulsarBinary):
 
     register = True
 
-    def __init__(self,):
-        super(BinaryDD, self).__init__()
+    def __init__(
+        self,
+    ):
+        super().__init__()
         self.binary_model_name = "DD"
         self.binary_model_class = DDmodel
         self.add_param(
@@ -76,8 +77,7 @@ class BinaryDD(PulsarBinary):
         )
 
     def validate(self):
-        """ Validate the input parameters.
-        """
+        """Validate the input parameters."""
         super().validate()
         self.check_required_params(["T0", "A1"])
         # If any *DOT is set, we need T0
