@@ -1,21 +1,18 @@
 """Approximate binary model for small eccentricity."""
-import logging
-from warnings import warn
-
 import astropy.units as u
 import numpy as np
 from astropy.time import Time
 
+from loguru import logger as log
+
 from pint.models.parameter import MJDParameter, floatParameter, intParameter
 from pint.models.pulsar_binary import PulsarBinary
 from pint.models.stand_alone_psr_binaries import binary_orbits as bo
 from pint.models.stand_alone_psr_binaries.ELL1_model import ELL1model
 from pint.models.stand_alone_psr_binaries.ELL1H_model import ELL1Hmodel
-from pint.models.timing_model import MissingParameter, TimingModelError
+from pint.models.timing_model import MissingParameter
 from pint.utils import taylor_horner_deriv
 
-log = logging.getLogger(__name__)
-
 
 class BinaryELL1(PulsarBinary):
     """ELL1 binary model.
@@ -108,7 +105,7 @@ class BinaryELL1(PulsarBinary):
 
         TASC will be changed to the epoch of the ascending node closest to the
         supplied epoch, and the Laplace parameters (EPS1, EPS2) and projected
-        semimajor axis (A1 or X) will be updated according to the specified
+        semi-major axis (A1 or X) will be updated according to the specified
         EPS1DOT, EPS2DOT, and A1DOT or XDOT, if present.
 
         Note that derivatives of binary orbital frequency higher than the first
@@ -137,18 +134,18 @@ class BinaryELL1(PulsarBinary):
         else:
             PB = 1.0 / self.FB0.quantity
             try:
-                PBDOT = -self.FB1.quantity / self.FB0.quantity ** 2
+                PBDOT = -self.FB1.quantity / self.FB0.quantity**2
             except AttributeError:
                 PBDOT = 0.0 * u.Unit("")
 
         # Find closest periapsis time and reassign T0
         tasc_ld = self.TASC.quantity.tdb.mjd_long
         dt = (new_epoch.tdb.mjd_long - tasc_ld) * u.day
-        d_orbits = dt / PB - PBDOT * dt ** 2 / (2.0 * PB ** 2)
+        d_orbits = dt / PB - PBDOT * dt**2 / (2.0 * PB**2)
         n_orbits = np.round(d_orbits.to(u.Unit("")))
         if n_orbits == 0:
             return
-        dt_integer_orbits = PB * n_orbits + PB * PBDOT * n_orbits ** 2 / 2.0
+        dt_integer_orbits = PB * n_orbits + PB * PBDOT * n_orbits**2 / 2.0
         self.TASC.quantity = self.TASC.quantity + dt_integer_orbits
 
         if hasattr(self, "FB2") and self.FB2.value is not None:
