@@ -17,7 +17,7 @@ from pint.utils import split_prefixed_name, taylor_horner, taylor_horner_deriv
 
 # This value is cited from Duncan Lorimer, Michael Kramer, Handbook of Pulsar
 # Astronomy, Second edition, Page 86, Note 1
-DMconst = 1.0 / 2.41e-4 * u.MHz * u.MHz * u.s * u.cm ** 3 / u.pc
+DMconst = 1.0 / 2.41e-4 * u.MHz * u.MHz * u.s * u.cm**3 / u.pc
 
 
 class Dispersion(DelayComponent):
@@ -84,7 +84,7 @@ class Dispersion(DelayComponent):
         param_name : str
             Derivative parameter name
         acc_delay : `astropy.quantity` or `numpy.ndarray`
-            Accumlated delay values. This parameter is to keep the unified API,
+            Accumulated delay values. This parameter is to keep the unified API,
             but not used in this function.
         """
         try:
@@ -93,10 +93,10 @@ class Dispersion(DelayComponent):
             warn("Using topocentric frequency for dedispersion!")
             bfreq = toas.table["freq"]
         param_unit = getattr(self, param_name).units
-        d_dm_d_dmparam = np.zeros(toas.ntoas) * u.pc / u.cm ** 3 / param_unit
+        d_dm_d_dmparam = np.zeros(toas.ntoas) * u.pc / u.cm**3 / param_unit
         for df in self.dm_deriv_funcs[param_name]:
             d_dm_d_dmparam += df(toas, param_name)
-        return DMconst * d_dm_d_dmparam / bfreq ** 2.0
+        return DMconst * d_dm_d_dmparam / bfreq**2.0
 
     def register_dm_deriv_funcs(self, func, param):
         """Register the derivative function in to the deriv_func dictionaries.
@@ -115,7 +115,7 @@ class Dispersion(DelayComponent):
             self.dm_deriv_funcs[pn] = [func]
         else:
             # TODO:
-            # Runing setup() mulitple times can lead to adding derivative
+            # Running setup() multiple times can lead to adding derivative
             # function multiple times. This prevent it from happening now. But
             # in the future, we should think a better way to do so.
             if func in self.dm_deriv_funcs[pn]:
@@ -229,7 +229,7 @@ class DispersionDM(Dispersion):
 
     def print_par(self, format="pint"):
         # TODO we need to have a better design for print out the parameters in
-        # an inhertance class.
+        # an inheritance class.
         result = ""
         prefix_dm = list(self.get_prefix_mapping_component("DM").values())
         dms = ["DM"] + prefix_dm
@@ -344,13 +344,13 @@ class DispersionDMX(Dispersion):
         Parameters
         ----------
 
-        mjd_start : float
+        mjd_start : float or astropy.quantity.Quantity or astropy.time.Time
             MJD for beginning of DMX event.
-        mjd_end : float
+        mjd_end : float or astropy.quantity.Quantity or astropy.time.Time
             MJD for end of DMX event.
         index : int, None
             Integer label for DMX event. If None, will increment largest used index by 1.
-        dmx : float
+        dmx : float or astropy.quantity.Quantity
             Change in DM during DMX event.
         frozen : bool
             Indicates whether DMX will be fit.
@@ -381,6 +381,16 @@ class DispersionDMX(Dispersion):
                 % index
             )
 
+        if isinstance(dmx, u.quantity.Quantity):
+            dmx = dmx.to_value(u.pc / u.cm**3)
+        if isinstance(mjd_start, Time):
+            mjd_start = mjd_start.mjd
+        elif isinstance(mjd_start, u.quantity.Quantity):
+            mjd_start = mjd_start.value
+        if isinstance(mjd_end, Time):
+            mjd_end = mjd_end.mjd
+        elif isinstance(mjd_end, u.quantity.Quantity):
+            mjd_end = mjd_end.value
         self.add_param(
             prefixParameter(
                 name="DMX_" + i,
@@ -431,7 +441,9 @@ class DispersionDMX(Dispersion):
             or isinstance(index, np.int64)
         ):
             indices = [index]
-        elif not isinstance(index, list) or not isinstance(index, np.ndarray):
+        elif isinstance(index, (list, np.ndarray)):
+            indices = index
+        else:
             raise TypeError(
                 f"index must be a float, int, list, or array - not {type(index)}"
             )
@@ -550,7 +562,7 @@ class DispersionDMX(Dispersion):
         dmx = np.zeros(len(tbl))
         for k, v in select_idx.items():
             dmx[v] = 1.0
-        return dmx * (u.pc / u.cm ** 3) / (u.pc / u.cm ** 3)
+        return dmx * (u.pc / u.cm**3) / (u.pc / u.cm**3)
 
     def print_par(self, format="pint"):
         result = ""
@@ -567,7 +579,7 @@ class DispersionDMX(Dispersion):
 
 
 class DispersionJump(Dispersion):
-    """This class provides the contant offsets to the DM values.
+    """This class provides the constant offsets to the DM values.
 
     Parameters supported:
 
