@@ -94,12 +94,12 @@ class IFunc(PhaseComponent):
             if (i + 1) != term:
                 raise MissingParameter("IFunc", "IFUNC%d" % (i + 1))
 
-    def print_par(self):
-        result = self.SIFUNC.as_parfile_line()
+    def print_par(self, format="pint"):
+        result = self.SIFUNC.as_parfile_line(format=format)
         terms = ["IFUNC%d" % ii for ii in range(1, self.num_terms + 1)]
         for ft in terms:
             par = getattr(self, ft)
-            result += par.as_parfile_line()
+            result += par.as_parfile_line(format=format)
 
         return result
 
