@@ -1,13 +1,10 @@
-import logging
-import os
-import tempfile
 import copy
+import warnings
 from io import StringIO
 from collections import Counter, defaultdict
+from pathlib import Path
+
 from pint.models.parameter import maskParameter
-from astropy import log
-import warnings
-from astropy.utils.decorators import lazyproperty
 from pint.models.timing_model import (
     DEFAULT_ORDER,
     Component,
@@ -25,8 +22,6 @@ from pint.models.timing_model import (
 from pint.toa import get_TOAs
 from pint.utils import PrefixError, interesting_lines, lines_of, split_prefixed_name
 
-log = logging.getLogger(__name__)
-
 
 __all__ = ["ModelBuilder", "get_model", "get_model_and_toas"]
 
@@ -34,19 +29,19 @@ default_models = ["StandardTimingModel"]
 
 
 class ComponentConflict(ValueError):
-    """Error for mulitple components can be select but no other indications."""
+    """Error for multiple components can be select but no other indications."""
 
 
 def parse_parfile(parfile):
     """Function for parsing .par file or .par style StringIO.
 
-    Parameter
-    ---------
+    Parameters
+    ----------
     parfile: str or file-like object
         Input .par file name or string contents.
 
-    Return
-    ------
+    Returns
+    -------
     dict:
         Parameter and its associated lines. The key is the parameter name and
         the value is a list of the lines associated to the parameter name.
@@ -62,10 +57,11 @@ class ModelBuilder:
     """Class for building a `TimingModel` object from a parameter file.
 
     The ModelBuilder class helps building a TimingModel from a parameter file
-    (i.e., pulsar ephemerise or '.par' file).
+    (i.e., pulsar ephemeris or '.par' file).
     It first maps the provided parameter names to the PINT defined parameter
     names, if they are in the PINT parameter aliases list. Then, the
     ModelBuilder selects model components based on the following rules:
+
         * The components in the :py:attr:`~default_components` list will be selected.
         * When a component get mapped uniquely by the given parameters.
         * The pulsar binary component will be selected by the 'BINARY' parameter.
@@ -80,8 +76,8 @@ class ModelBuilder:
     def __call__(self, parfile, allow_name_mixing=False):
         """Callable object for making a timing model from .par file.
 
-        Parameter
-        ---------
+        Parameters
+        ----------
         parfile: str or file-like object
             Input .par file name or string contents
 
@@ -91,8 +87,8 @@ class ModelBuilder:
             T2EFAC and EFAC, both of them maps to PINT parameter EFAC, present
             in the parfile at the same time.
 
-        Return
-        ------
+        Returns
+        -------
         pint.models.timing_model.TimingModel
             The result timing model based on the input .parfile or file object.
         """
@@ -112,6 +108,7 @@ class ModelBuilder:
         for k, v in unknown_param.items():
             p_line = " ".join([k] + v)
             warnings.warn(f"Unrecognized parfile line '{p_line}'", UserWarning)
+            # log.warning(f"Unrecognized parfile line '{p_line}'")
         return tm
 
     def _validate_components(self):
@@ -140,20 +137,21 @@ class ModelBuilder:
                     raise ComponentConflict(m)
 
     def _get_component_param_overlap(self, component):
-        """Check the parameter overlaping between two components.
+        """Check the parameter overlapping between two components.
 
-        Check if one component's parameters are overlaped with another
+        Check if one component's parameters are overlapped with another
         component.
 
         Parameters
         ----------
         components: pint.models.timing_model.Component
             The component to be checked.
+
         Returns
         -------
         overlap : dict
-            The component has overlap parameters and the overlaping parameters
-            in the format of {overlap compnent name: (overlap parameter,
+            The component has overlap parameters and the overlapping parameters
+            in the format of {overlap component name: (overlap parameter,
             number of non-overlap param in test component,
             number of non-overlap param in overlap component) }
         """
@@ -220,7 +218,7 @@ class ModelBuilder:
                 Pintified parameter dictionary with the PINT name as key and list of
                 parameter value-uncertainty lines as value. For the
                 repeating parameters in the parfile, the value will contain
-                mulitple lines.
+                multiple lines.
 
             original_name_map : dict
                 PINT name maps to the original .par file input names. PINT name
@@ -234,13 +232,13 @@ class ModelBuilder:
         Raises
         ------
         TimingModelError
-            If the parfile has mulitple line with non-repeating parameters.
+            If the parfile has multiple line with non-repeating parameters.
         """
         pint_param_dict = defaultdict(list)
         original_name_map = defaultdict(list)
         unknown_param = defaultdict(list)
         repeating = Counter()
-        if isinstance(parfile, (str, StringIO)):
+        if isinstance(parfile, (str, StringIO, Path)):
             parfile_dict = parse_parfile(parfile)
         else:
             parfile_dict = parfile
@@ -268,7 +266,7 @@ class ModelBuilder:
                 if pint_name not in self.all_components.repeatable_param:
                     raise TimingModelError(
                         f"Parameter {pint_name} is not a repeatable parameter. "
-                        f"However, mulitple line use it."
+                        f"However, multiple line use it."
                     )
         # Check if the name is mixed
         for p_n, o_n in original_name_map.items():
@@ -287,14 +285,14 @@ class ModelBuilder:
     def choose_model(self, param_inpar):
         """Choose the model components based on the parfile.
 
-        Parameter
-        ---------
+        Parameters
+        ----------
         param_inpar: dict
             Dictionary of the unique parameters in .par file with the key is the
-        parfile line. :func:`parse_parfile` returns this dictionary.
+            parfile line. :func:`parse_parfile` returns this dictionary.
 
-        Return
-        ------
+        Returns
+        -------
         list
             List of selected components.
         dict
@@ -308,14 +306,15 @@ class ModelBuilder:
         Note
         ----
         The selection algorithm:
-            #. Look at the BINARY in the par file and catche the indicated binary model
+            #. Look at the BINARY in the par file and cache the indicated binary model
             #. Translate para file parameters to the pint parameter name
             #. Go over the parameter-component map and pick up the components based
                on the parameters in parfile.
+
                 #. Select the components that have its unique parameters in the parfile.
                    In other words, select the components that have one parameter to
                    on component mapping.
-                #. Log the conflict components, one parameter to mulitple components mapping.
+                #. Log the conflict components, one parameter to multiple components mapping.
         """
         selected_components = set()
         param_count = Counter()
@@ -428,7 +427,7 @@ class ModelBuilder:
         it will search matching key value pair first. If the input parameter line's
         key-value matches the existing parameter, the parameter value and uncertainty
         will copy to the existing parameter. If there is no match, it will find an
-        empty existing parameter, whose `key` is `None`, and fill it up. If no empyt
+        empty existing parameter, whose `key` is `None`, and fill it up. If no empty
         parameter left, it will add a new parameter to it.
 
         Parameters
@@ -436,20 +435,19 @@ class ModelBuilder:
         timing_model : pint.models.TimingModel
             Timing model to get setup.
         pint_param_dict: dict
-            Pintified parfile dictionary which can be aquired by
+            Pintified parfile dictionary which can be acquired by
             :meth:`ModelBuilder._pintify_parfile`
-        origin_name : dict, optional
+        original_name : dict, optional
             A map from PINT name to the original input name.
         setup : bool, optional
             Whether to run the setup function in the timing model.
         validate : bool, optional
-            Whether to run the validate funciotn in the timing model.
+            Whether to run the validate function in the timing model.
         """
         if original_name is not None:
             use_alias = True
         else:
             use_alias = False
-
         for pp, v in pint_param_dict.items():
             try:
                 par = getattr(timing_model, pp)
@@ -468,7 +466,7 @@ class ModelBuilder:
                         f" timing model. It is used in {par_hosts},"
                         f" but the current timing model uses {currnt_cp}."
                     )
-                # TODO need to create a beeter API for _loacte_param_host
+                # TODO need to create a better API for _locate_param_host
                 host_component = timing_model._locate_param_host(first_init)
                 timing_model.add_param_from_top(
                     getattr(timing_model, first_init).new_param(index),
@@ -479,7 +477,7 @@ class ModelBuilder:
             # Fill up the values
             param_line = len(v)
             if param_line < 2:
-                if use_alias:  # Use the input alias as input
+                if use_alias:
                     name = original_name[pp]
                 else:
                     name = pp
@@ -490,7 +488,7 @@ class ModelBuilder:
                 example_par = getattr(timing_model, pp)
                 prefix, _, index = split_prefixed_name(pp)
                 for li in lines:
-                    # Creat a temp parameter with the idx bigger than all the existing indices
+                    # Create a temp parameter with the idx bigger than all the existing indices
                     repeatable_map = timing_model.get_prefix_mapping(prefix)
                     new_max_idx = max(repeatable_map.keys()) + 1
                     temp_par = example_par.new_param(new_max_idx)
@@ -535,8 +533,7 @@ class ModelBuilder:
         return timing_model
 
     def _report_conflict(self, conflict_graph):
-        """Report conflict components
-        """
+        """Report conflict components"""
         for k, v in conflict_graph.items():
             # Put all the conflict components together from the graph
             cf_cps = list(v)
@@ -577,12 +574,8 @@ def get_model(parfile, allow_name_mixing=False):
         model.name = parfile
         return model
     else:
-        with tempfile.TemporaryDirectory() as td:
-            fn = os.path.join(td, "temp.par")
-            with open(fn, "wt") as f:
-                f.write(contents)
-            tm = model_builder(fn, allow_name_mixing)
-            return tm
+        tm = model_builder(StringIO(contents), allow_name_mixing)
+        return tm
 
 
 def get_model_and_toas(
@@ -595,8 +588,10 @@ def get_model_and_toas(
     planets=None,
     usepickle=False,
     tdb_method="default",
+    include_pn=True,
     picklefilename=None,
     allow_name_mixing=False,
+    limits="warn",
 ):
     """Load a timing model and a related TOAs, using model commands as needed
 
@@ -622,6 +617,8 @@ def get_model_and_toas(
     tdb_method : str
         Which method to use for the clock correction to TDB. See
         :func:`pint.observatory.Observatory.get_TDBs` for details.
+    include_pn : bool, optional
+        Whether or not to read in the 'pn' column (``pulse_number``)
     picklefilename : str or None
         Filename to use for caching loaded file. Defaults to adding ``.pickle.gz`` to the
         filename of the timfile, if there is one and only one. If no filename is available,
@@ -631,6 +628,9 @@ def get_model_and_toas(
         same parameter. For example, if this flag is true, one can have
         T2EFAC and EFAC, both of them maps to PINT parameter EFAC, present
         in the parfile at the same time.
+    limits : "warn" or "error"
+        What to do when encountering TOAs for which clock corrections are not available.
+
     Returns
     -------
     A tuple with (model instance, TOAs instance)
@@ -638,6 +638,7 @@ def get_model_and_toas(
     mm = get_model(parfile, allow_name_mixing)
     tt = get_TOAs(
         timfile,
+        include_pn=include_pn,
         model=mm,
         ephem=ephem,
         include_bipm=include_bipm,
@@ -647,5 +648,6 @@ def get_model_and_toas(
         usepickle=usepickle,
         tdb_method=tdb_method,
         picklefilename=picklefilename,
+        limits=limits,
     )
     return mm, tt
