@@ -1,28 +1,29 @@
 """Pulsar timing noise models."""
 
 import copy
-import logging
 import warnings
 
 import astropy.units as u
 import numpy as np
 
+from loguru import logger as log
+
 from pint.models.parameter import floatParameter, maskParameter
 from pint.models.timing_model import Component
 
-log = logging.getLogger(__name__)
-
 
 class NoiseComponent(Component):
-    def __init__(self,):
+    def __init__(
+        self,
+    ):
         super().__init__()
         self.covariance_matrix_funcs = []
-        self.scaled_toa_sigma_funcs = []  # Need to move this to a speical place.
+        self.scaled_toa_sigma_funcs = []  # Need to move this to a special place.
         self.scaled_dm_sigma_funcs = []
         # TODO This works right now. But if we want to expend noise model, we
         # need to think about the design now. If we do not define the list
         # here and calling the same name from other component, it will get
-        # it from the component that hosts it. It has the risk to dulicate
+        # it from the component that hosts it. It has the risk to duplicate
         # the list elements.
         self.dm_covariance_matrix_funcs_component = []
         self.basis_funcs = []
@@ -38,16 +39,20 @@ class ScaleToaError(NoiseComponent):
 
     Note
     ----
-    Ref: NanoGrav 11 yrs data
+    Ref: NANOGrav 11 yrs data
 
     """
 
     register = True
     category = "scale_toa_error"
 
-    def __init__(self,):
+    introduces_correlated_errors = False
+
+    def __init__(
+        self,
+    ):
         super().__init__()
-        self.introduces_correlated_errors = False
+
         self.add_param(
             maskParameter(
                 name="EFAC",
@@ -182,15 +187,18 @@ class ScaleDmError(NoiseComponent):
 
     Note
     ----
-    Ref: NanoGrav 12.5 yrs wideband data
+    Ref: NANOGrav 12.5 yrs wideband data
     """
 
     register = True
     category = "scale_dm_error"
 
-    def __init__(self,):
+    introduces_correlated_errors = False
+
+    def __init__(
+        self,
+    ):
         super().__init__()
-        self.introduces_correlated_errors = False
         self.add_param(
             maskParameter(
                 name="DMEFAC",
@@ -269,7 +277,7 @@ class ScaleDmError(NoiseComponent):
         return sigma_scaled
 
     def dm_sigma_scaled_cov_matrix(self, toas):
-        scaled_sigma = self.scale_dm_sigma(toas).to_value(u.pc / u.cm ** 3) ** 2
+        scaled_sigma = self.scale_dm_sigma(toas).to_value(u.pc / u.cm**3) ** 2
         return np.diag(scaled_sigma)
 
 
@@ -288,16 +296,19 @@ class EcorrNoise(NoiseComponent):
 
     Note
     ----
-    Ref: NanoGrav 11 yrs data
+    Ref: NANOGrav 11 yrs data
 
     """
 
     register = True
     category = "ecorr_noise"
 
-    def __init__(self,):
+    introduces_correlated_errors = True
+
+    def __init__(
+        self,
+    ):
         super().__init__()
-        self.introduces_correlated_errors = True
         self.add_param(
             maskParameter(
                 name="ECORR",
@@ -338,12 +349,10 @@ class EcorrNoise(NoiseComponent):
             ecorrs.append(getattr(self, ecorr))
         return ecorrs
 
-    def ecorr_basis_weight_pair(self, toas):
-        """Return a quantization matrix and ECORR weights.
+    def get_noise_basis(self, toas):
+        """Return the quantization matrix for ECORR.
 
         A quantization matrix maps TOAs to observing epochs.
-        The weights used are the square of the ECORR values.
-
         """
         tbl = toas.table
         t = (tbl["tdbld"].quantity * u.day).to(u.s).value
@@ -352,21 +361,45 @@ class EcorrNoise(NoiseComponent):
         for ec in ecorrs:
             mask = ec.select_toa_mask(toas)
             if np.any(mask):
-                umats.append(create_quantization_matrix(t[mask]))
+                umats.append(create_ecorr_quantization_matrix(t[mask]))
             else:
                 warnings.warn(f"ECORR {ec} has no TOAs")
                 umats.append(np.zeros((0, 0)))
         nc = sum(u.shape[1] for u in umats)
         umat = np.zeros((len(t), nc))
-        weight = np.zeros(nc)
         nctot = 0
         for ct, ec in enumerate(ecorrs):
             mask = ec.select_toa_mask(toas)
             nn = umats[ct].shape[1]
             umat[mask, nctot : nn + nctot] = umats[ct]
-            weight[nctot : nn + nctot] = ec.quantity.to(u.s).value ** 2
             nctot += nn
-        return (umat, weight)
+        return umat
+
+    def get_noise_weights(self, toas, nweights=None):
+        """Return the ECORR weights
+        The weights used are the square of the ECORR values.
+        """
+        ecorrs = self.get_ecorrs()
+        if nweights is None:
+            ts = (toas.table["tdbld"].quantity * u.day).to(u.s).value
+            nweights = [
+                get_ecorr_nweights(ts[ec.select_toa_mask(toas)]) for ec in ecorrs
+            ]
+        nc = sum(nweights)
+        weights = np.zeros(nc)
+        nctot = 0
+        for ec, nn in zip(ecorrs, nweights):
+            weights[nctot : nn + nctot] = ec.quantity.to(u.s).value ** 2
+            nctot += nn
+        return weights
+
+    def ecorr_basis_weight_pair(self, toas):
+        """Return a quantization matrix and ECORR weights.
+
+        A quantization matrix maps TOAs to observing epochs.
+        The weights used are the square of the ECORR values.
+        """
+        return (self.get_noise_basis(toas), self.get_noise_weights(toas))
 
     def ecorr_cov_matrix(self, toas):
         """Full ECORR covariance matrix."""
@@ -374,6 +407,119 @@ class EcorrNoise(NoiseComponent):
         return np.dot(U * Jvec[None, :], U.T)
 
 
+class PLDMNoise(NoiseComponent):
+    """Model of DM variations as radio frequency-dependent noise with a
+    power-law spectrum.
+
+    Variations in DM over time result from both the proper motion of the
+    pulsar and the changing electron number density along the line of sight
+    from the solar wind and ISM. In particular, Kolmogorov turbulence in the
+    ionized ISM will induce stochastic DM variations with a power law
+    spectrum. Timing errors due to unmodelled DM variations can therefore
+    appear very similar to intrinsic red noise, however the amplitude of these
+    variations will scale with the inverse of the square of the (Earth Doppler
+    corrected) radio frequency.
+
+    Parameters supported:
+
+    .. paramtable::
+        :class: pint.models.noise_model.PLDMNoise
+
+    Note
+    ----
+    Ref: Lentati et al. 2014
+
+    """
+
+    register = True
+    category = "pl_DM_noise"
+
+    introduces_correlated_errors = True
+
+    def __init__(
+        self,
+    ):
+        super().__init__()
+
+        self.add_param(
+            floatParameter(
+                name="TNDMAMP",
+                units="",
+                aliases=[],
+                description="Amplitude of powerlaw " "DM noise in tempo2 format",
+            )
+        )
+        self.add_param(
+            floatParameter(
+                name="TNDMGAM",
+                units="",
+                aliases=[],
+                description="Spectral index of powerlaw " "DM noise in tempo2 format",
+            )
+        )
+        self.add_param(
+            floatParameter(
+                name="TNDMC",
+                units="",
+                aliases=[],
+                description="Number of DM noise frequencies.",
+            )
+        )
+
+        self.covariance_matrix_funcs += [self.pl_dm_cov_matrix]
+        self.basis_funcs += [self.pl_dm_basis_weight_pair]
+
+    def get_pl_vals(self):
+        nf = int(self.TNDMC.value) if self.TNDMC.value is not None else 30
+        amp, gam = 10**self.TNDMAMP.value, self.TNDMGAM.value
+        return (amp, gam, nf)
+
+    def get_noise_basis(self, toas):
+        """Return a Fourier design matrix for DM noise.
+
+        See the documentation for pl_dm_basis_weight_pair function for details."""
+
+        tbl = toas.table
+        t = (tbl["tdbld"].quantity * u.day).to(u.s).value
+        freqs = self._parent.barycentric_radio_freq(toas).to(u.MHz)
+        fref = 1400 * u.MHz
+        D = (fref.value / freqs.value) ** 2
+        nf = self.get_pl_vals()[2]
+        Fmat = create_fourier_design_matrix(t, nf)
+        return Fmat * D[:, None]
+
+    def get_noise_weights(self, toas):
+        """Return power law DM noise weights.
+
+        See the documentation for pl_dm_basis_weight_pair for details."""
+
+        tbl = toas.table
+        t = (tbl["tdbld"].quantity * u.day).to(u.s).value
+        amp, gam, nf = self.get_pl_vals()
+        Ffreqs = get_rednoise_freqs(t, nf)
+        weights = powerlaw(Ffreqs, amp, gam) * Ffreqs[0]
+        return weights
+
+    def pl_dm_basis_weight_pair(self, toas):
+        """Return a Fourier design matrix and power law DM noise weights.
+
+        A Fourier design matrix contains the sine and cosine basis_functions
+        in a Fourier series expansion. Here we scale the design matrix by
+        (fref/f)**2, where fref = 1400 MHz to match the convention used in
+        enterprise.
+
+        The weights used are the power-law PSD values at frequencies n/T,
+        where n is in [1, TNDMC] and T is the total observing duration of
+        the dataset.
+
+        """
+        return (self.get_noise_basis(toas), self.get_noise_weights(toas))
+
+    def pl_dm_cov_matrix(self, toas):
+        Fmat, phi = self.pl_dm_basis_weight_pair(toas)
+        return np.dot(Fmat * phi[None, :], Fmat.T)
+
+
 class PLRedNoise(NoiseComponent):
     """Timing noise with a power-law spectrum.
 
@@ -391,16 +537,20 @@ class PLRedNoise(NoiseComponent):
 
     Note
     ----
-    Ref: NanoGrav 11 yrs data
+    Ref: NANOGrav 11 yrs data
 
     """
 
     register = True
     category = "pl_red_noise"
 
-    def __init__(self,):
+    introduces_correlated_errors = True
+
+    def __init__(
+        self,
+    ):
         super().__init__()
-        self.introduces_correlated_errors = True
+
         self.add_param(
             floatParameter(
                 name="RNAMP",
@@ -420,7 +570,7 @@ class PLRedNoise(NoiseComponent):
 
         self.add_param(
             floatParameter(
-                name="TNRedAmp",
+                name="TNREDAMP",
                 units="",
                 aliases=[],
                 description="Amplitude of powerlaw " "red noise in tempo2 format",
@@ -428,7 +578,7 @@ class PLRedNoise(NoiseComponent):
         )
         self.add_param(
             floatParameter(
-                name="TNRedGam",
+                name="TNREDGAM",
                 units="",
                 aliases=[],
                 description="Spectral index of powerlaw " "red noise in tempo2 format",
@@ -436,7 +586,7 @@ class PLRedNoise(NoiseComponent):
         )
         self.add_param(
             floatParameter(
-                name="TNRedC",
+                name="TNREDC",
                 units="",
                 aliases=[],
                 description="Number of red noise frequencies.",
@@ -447,38 +597,59 @@ class PLRedNoise(NoiseComponent):
         self.basis_funcs += [self.pl_rn_basis_weight_pair]
 
     def get_pl_vals(self):
-        nf = int(self.TNRedC.value) if self.TNRedC.value is not None else 30
-        if self.TNRedAmp.value is not None and self.TNRedGam.value is not None:
-            amp, gam = 10 ** self.TNRedAmp.value, self.TNRedGam.value
+        nf = int(self.TNREDC.value) if self.TNREDC.value is not None else 30
+        if self.TNREDAMP.value is not None and self.TNREDGAM.value is not None:
+            amp, gam = 10**self.TNREDAMP.value, self.TNREDGAM.value
         elif self.RNAMP.value is not None and self.RNIDX is not None:
             fac = (86400.0 * 365.24 * 1e6) / (2.0 * np.pi * np.sqrt(3.0))
             amp, gam = self.RNAMP.value / fac, -1 * self.RNIDX.value
         return (amp, gam, nf)
 
+    def get_noise_basis(self, toas):
+        """Return a Fourier design matrix for red noise.
+
+        See the documentation for pl_rn_basis_weight_pair function for details."""
+
+        tbl = toas.table
+        t = (tbl["tdbld"].quantity * u.day).to(u.s).value
+        nf = self.get_pl_vals()[2]
+        Fmat = create_fourier_design_matrix(t, nf)
+        return Fmat
+
+    def get_noise_weights(self, toas):
+        """Return power law red noise weights.
+
+        See the documentation for pl_rn_basis_weight_pair for details."""
+
+        tbl = toas.table
+        t = (tbl["tdbld"].quantity * u.day).to(u.s).value
+        amp, gam, nf = self.get_pl_vals()
+        Ffreqs = get_rednoise_freqs(t, nf)
+        weights = powerlaw(Ffreqs, amp, gam) * Ffreqs[0]
+        return weights
+
     def pl_rn_basis_weight_pair(self, toas):
-        """Return a Fourier design matrix and red noise weights.
+        """Return a Fourier design matrix and power law red noise weights.
 
         A Fourier design matrix contains the sine and cosine basis_functions
         in a Fourier series expansion.
         The weights used are the power-law PSD values at frequencies n/T,
-        where n is in [1, TNRedC] and T is the total observing duration of
+        where n is in [1, TNREDC] and T is the total observing duration of
         the dataset.
 
         """
-        tbl = toas.table
-        t = (tbl["tdbld"].quantity * u.day).to(u.s).value
-        amp, gam, nf = self.get_pl_vals()
-        Fmat, f = create_fourier_design_matrix(t, nf)
-        weight = powerlaw(f, amp, gam) * f[0]
-        return (Fmat, weight)
+        return (self.get_noise_basis(toas), self.get_noise_weights(toas))
 
     def pl_rn_cov_matrix(self, toas):
         Fmat, phi = self.pl_rn_basis_weight_pair(toas)
         return np.dot(Fmat * phi[None, :], Fmat.T)
 
 
-def create_quantization_matrix(toas_table, dt=1, nmin=2):
-    """Create quantization matrix mapping TOAs to observing epochs."""
+def get_ecorr_epochs(toas_table, dt=1, nmin=2):
+    """Find only epochs with more than 1 TOA for applying ECORR."""
+    if len(toas_table) == 0:
+        return []
+
     isort = np.argsort(toas_table)
 
     bucket_ref = [toas_table[isort[0]]]
@@ -491,9 +662,23 @@ def create_quantization_matrix(toas_table, dt=1, nmin=2):
             bucket_ref.append(toas_table[i])
             bucket_ind.append([i])
 
-    # find only epochs with more than 1 TOA
     bucket_ind2 = [ind for ind in bucket_ind if len(ind) >= nmin]
 
+    return bucket_ind2
+
+
+def get_ecorr_nweights(toas_table, dt=1, nmin=2):
+    """Get the number of epochs associated with each ECORR.
+    This is equal to the number of weights of that ECORR."""
+    return len(get_ecorr_epochs(toas_table, dt=dt, nmin=nmin))
+
+
+def create_ecorr_quantization_matrix(toas_table, dt=1, nmin=2):
+    """Create quantization matrix mapping TOAs to observing epochs.
+    Only epochs with more than 1 TOA are included."""
+
+    bucket_ind2 = get_ecorr_epochs(toas_table, dt=dt, nmin=nmin)
+
     U = np.zeros((len(toas_table), len(bucket_ind2)), "d")
     for i, l in enumerate(bucket_ind2):
         U[l, i] = 1
@@ -501,6 +686,23 @@ def create_quantization_matrix(toas_table, dt=1, nmin=2):
     return U
 
 
+def get_rednoise_freqs(t, nmodes, Tspan=None):
+    """Frequency components for creating the red noise basis matrix."""
+
+    if Tspan is not None:
+        T = Tspan
+    else:
+        T = t.max() - t.min()
+
+    f = np.linspace(1 / T, nmodes / T, nmodes)
+
+    Ffreqs = np.zeros(2 * nmodes)
+    Ffreqs[0::2] = f
+    Ffreqs[1::2] = f
+
+    return Ffreqs
+
+
 def create_fourier_design_matrix(t, nmodes, Tspan=None):
     """
     Construct fourier design matrix from eq 11 of Lentati et al, 2013
@@ -515,21 +717,12 @@ def create_fourier_design_matrix(t, nmodes, Tspan=None):
     N = len(t)
     F = np.zeros((N, 2 * nmodes))
 
-    if Tspan is not None:
-        T = Tspan
-    else:
-        T = t.max() - t.min()
+    Ffreqs = get_rednoise_freqs(t, nmodes, Tspan=Tspan)
 
-    f = np.linspace(1 / T, nmodes / T, nmodes)
+    F[:, ::2] = np.sin(2 * np.pi * t[:, None] * Ffreqs[0::2])
+    F[:, 1::2] = np.cos(2 * np.pi * t[:, None] * Ffreqs[1::2])
 
-    Ffreqs = np.zeros(2 * nmodes)
-    Ffreqs[0::2] = f
-    Ffreqs[1::2] = f
-
-    F[:, ::2] = np.sin(2 * np.pi * t[:, None] * f[None, :])
-    F[:, 1::2] = np.cos(2 * np.pi * t[:, None] * f[None, :])
-
-    return F, Ffreqs
+    return F
 
 
 def powerlaw(f, A=1e-16, gamma=5):
@@ -541,4 +734,4 @@ def powerlaw(f, A=1e-16, gamma=5):
     """
 
     fyr = 1 / 3.16e7
-    return A ** 2 / 12.0 / np.pi ** 2 * fyr ** (gamma - 3) * f ** (-gamma)
+    return A**2 / 12.0 / np.pi**2 * fyr ** (gamma - 3) * f ** (-gamma)
