@@ -21,7 +21,6 @@ See :ref:`Supported Parameters` for an overview, including a table of all the
 parameters PINT understands.
 
 """
-import logging
 import numbers
 from warnings import warn
 
@@ -30,6 +29,8 @@ import astropy.units as u
 import numpy as np
 from astropy.coordinates.angles import Angle
 
+from loguru import logger as log
+
 from pint import pint_units
 from pint.models import priors
 from pint.observatory import get_observatory
@@ -46,8 +47,6 @@ from pint.pulsar_mjd import (
 from pint.toa_select import TOASelect
 from pint.utils import split_prefixed_name
 
-log = logging.getLogger(__name__)
-
 
 # potential parfile formats
 # in one place for consistency
@@ -283,7 +282,7 @@ class Parameter:
             self._units = pint_units[unt]
 
         else:
-            # Try to use it as an astopy unit.  If this fails,
+            # Try to use it as an astropy unit.  If this fails,
             # ValueError will be raised.
             self._units = u.Unit(unt)
 
@@ -455,9 +454,10 @@ class Parameter:
 
         .. [1] https://github.com/nanograv/PINT/wiki/PINT-vs.-TEMPO%282%29-par-file-changes
         """
-        assert format.lower() in _parfile_formats, (
-            "parfile format must be one of %s"
-            % ", ".join(['"%s"' % x for x in _parfile_formats])
+        assert (
+            format.lower() in _parfile_formats
+        ), "parfile format must be one of %s" % ", ".join(
+            ['"%s"' % x for x in _parfile_formats]
         )
 
         # Don't print unset parameters
@@ -487,7 +487,7 @@ class Parameter:
         # special cases for parameter values that change depending on format
         if self.name == "ECL" and format.lower() == "tempo2":
             if self.value != "IERS2003":
-                warn(
+                log.warning(
                     f"Changing ECL from '{self.value}' to 'IERS2003'; please refit for consistent results"
                 )
                 # change ECL value to IERS2003 for TEMPO2
@@ -498,15 +498,17 @@ class Parameter:
         elif self.name == "KIN" and format.lower() == "tempo":
             # convert from DT92 convention to IAU
             line = "%-15s %25s" % (name, self.str_quantity(180 * u.deg - self.quantity))
-            warn(
+            log.warning(
                 f"Changing KIN from DT92 convention to IAU: this will not be readable by PINT"
             )
         elif self.name == "KOM" and format.lower() == "tempo":
             # convert from DT92 convention to IAU
             line = "%-15s %25s" % (name, self.str_quantity(90 * u.deg - self.quantity))
-            warn(
+            log.warning(
                 f"Changing KOM from DT92 convention to IAU: this will not be readable by PINT"
             )
+        elif self.name == "DMDATA" and not format.lower() == "pint":
+            line = "%-15s %d" % (self.name, int(self.value))
 
         if self.uncertainty is not None:
             line += " %d %s" % (
@@ -581,8 +583,10 @@ class Parameter:
 
     def name_matches(self, name):
         """Whether or not the parameter name matches the provided name"""
-        return (name == self.name.upper()) or (
-            name in [x.upper() for x in self.aliases]
+        return (
+            (name == self.name.upper())
+            or (name in [x.upper() for x in self.aliases])
+            or (split_prefixed_name(name) == split_prefixed_name(self.name.upper()))
         )
 
     def set(self, value):
@@ -949,7 +953,7 @@ class intParameter(Parameter):
             except ValueError:
                 fval = float(val)
                 ival = int(fval)
-                if ival != fval and abs(fval) < 2 ** 52:
+                if ival != fval and abs(fval) < 2**52:
                     raise ValueError(
                         f"Value {val} does not appear to be an integer "
                         f"but parameter {self.name} stores only integers."
@@ -958,7 +962,7 @@ class intParameter(Parameter):
         else:
             ival = int(val)
             fval = float(val)
-            if ival != fval and abs(fval) < 2 ** 52:
+            if ival != fval and abs(fval) < 2**52:
                 raise ValueError(
                     f"Value {val} does not appear to be an integer "
                     f"but parameter {self.name} stores only integers."
@@ -1249,15 +1253,15 @@ class AngleParameter(Parameter):
 class prefixParameter:
     """Families of parameters identified by a prefix like ``DMX_0123``.
 
-    Create a prefix parameter, is like create a normal parameter. But the
-    name should be in the format of prefix and index. For example DMX_0001 or
-    F22. Appropriate units will be inferred,
+    Creating a ``prefixParameter`` is like creating a normal parameter, except that the
+    name should be in the format of prefix and index. For example, ``DMX_0001`` or
+    ``F22``. Appropriate units will be inferred.
 
     To create a prefix parameter with the same prefix but different index, just
-    use the ``.new_param`` method. It will return a new prefix parameter with the
-    same setup but the index. Some parameters' unit and description will
-    be changed once the index has been changed. In order to get the right units
-    and description, ``.unitTplt`` and ``.descriptionTplt`` should be provided. If
+    use the :meth:`pint.models.parameter.prefixParameter.new_param` method. It will return a new ``prefixParameter`` with the
+    same setup but a new index. Some  units and descriptions will
+    be changed once the index has been changed. The new parameter will not inherit the ``frozen`` status of its parent by default.  In order to get the right units
+    and description, ``.unit_template`` and ``.description_template`` should be provided. If
     not the new prefix parameter will use the same units and description with
     the old one. A typical description and units template is like::
 
@@ -1334,7 +1338,7 @@ class prefixParameter:
         try:
             self.param_class = self.type_mapping[self.parameter_type.lower()]
         except KeyError:
-            raise ValueError("Unknow parameter type '" + parameter_type + "' ")
+            raise ValueError("Unknown parameter type '" + parameter_type + "' ")
 
         # Set up other attributes in the wrapper class
         self.unit_template = unit_template
@@ -1345,7 +1349,7 @@ class prefixParameter:
         # set templates, the templates should be a named function and input is
         # the index of prefix parameter.
 
-        # Set the description and units for the parameter compostion.
+        # Set the description and units for the parameter composition.
         if self.unit_template is not None:
             real_units = self.unit_template(self.index)
         else:
@@ -1500,13 +1504,15 @@ class prefixParameter:
     def prefix_matches(self, prefix):
         return (prefix == self.prefix) or (prefix in self.prefix_aliases)
 
-    def new_param(self, index):
+    def new_param(self, index, inheritfrozen=False):
         """Get one prefix parameter with the same type.
 
         Parameters
         ----------
         index : int
             index of prefixed parameter.
+        inheritfrozen : bool, optional
+            whether or not the parameter should inherit the "frozen" status of the base parameter
 
         Returns
         -------
@@ -1528,6 +1534,8 @@ class prefixParameter:
             "parameter_type",
         ]:
             if hasattr(self, key):
+                if (key == "frozen") and not (inheritfrozen):
+                    continue
                 kws[key] = getattr(self, key)
 
         newpfx = prefixParameter(name=new_name, **kws)
@@ -1786,9 +1794,10 @@ class maskParameter(floatParameter):
         return True
 
     def as_parfile_line(self, format="pint"):
-        assert format.lower() in _parfile_formats, (
-            "parfile format must be one of %s"
-            % ", ".join(['"%s"' % x for x in _parfile_formats])
+        assert (
+            format.lower() in _parfile_formats
+        ), "parfile format must be one of %s" % ", ".join(
+            ['"%s"' % x for x in _parfile_formats]
         )
 
         if self.quantity is None:
@@ -1902,14 +1911,16 @@ class maskParameter(floatParameter):
     def compare_key_value(self, other_param):
         """Compare if the key and value are the same with the other parameter.
 
-        Parameter
-        ---------
+        Parameters
+        ----------
         other_param: maskParameter
             The parameter to compare.
+
         Return
         ------
         bool:
             If the key and value are the same, return True, otherwise False.
+
         Raises
         ------
         ValueError:
