@@ -7,7 +7,6 @@ such as total proper motion, 2-d sky location, etc.
 
 """
 import numpy as np
-import scipy.stats
 from scipy.stats import norm, rv_continuous, rv_discrete, uniform
 
 
@@ -44,7 +43,7 @@ class Prior:
 
         >>> model.PB.prior = Prior(scipy.stats.norm(loc=32.0,scale=1.0))
 
-    A bounded gaussian prior that ensure that eccentrity never gets > 1.0
+    A bounded gaussian prior that ensure that eccentricity never gets > 1.0
 
         >>> model.ECC.prior = Prior(GaussianBoundedRV(loc=0.9,scale=0.1,
         ...            lower_bound=0.0,upper_bound=1.0))
@@ -80,13 +79,13 @@ class RandomInclinationPrior(rv_continuous):
     def __init__(self, **kwargs):
         kwargs["a"] = 0
         kwargs["b"] = 1
-        super(RandomInclinationPrior, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def _pdf(self, v):
-        return v / (1 - v ** 2) ** 0.5
+        return v / (1 - v**2) ** 0.5
 
     def _logpdf(self, v):
-        return np.log(v) - 0.5 * np.log(1 - v ** 2)
+        return np.log(v) - 0.5 * np.log(1 - v**2)
 
 
 class UniformUnboundedRV(rv_continuous):
@@ -133,7 +132,7 @@ class GaussianRV_gen(rv_continuous):
     """
 
     def _pdf(self, x):
-        ret = np.exp(-(x ** 2) / 2) / np.sqrt(2 * np.pi)
+        ret = np.exp(-(x**2) / 2) / np.sqrt(2 * np.pi)
         return ret
 
 
