@@ -3,19 +3,24 @@
 This module if for wrapping standalone binary models so that they work
 as PINT timing models.
 """
-import logging
 
 import astropy.units as u
 import numpy as np
 from astropy.time import Time
+from astropy.coordinates import SkyCoord
+from loguru import logger as log
 
 from pint import ls
 from pint.models.parameter import MJDParameter, floatParameter, prefixParameter
 from pint.models.stand_alone_psr_binaries import binary_orbits as bo
-from pint.models.timing_model import DelayComponent, MissingParameter, UnknownParameter
+from pint.models.timing_model import (
+    DelayComponent,
+    MissingParameter,
+    TimingModelError,
+    UnknownParameter,
+)
 from pint.utils import taylor_horner_deriv
-
-log = logging.getLogger(__name__)
+from pint.pulsar_ecliptic import PulsarEcliptic
 
 
 class PulsarBinary(DelayComponent):
@@ -75,7 +80,7 @@ class PulsarBinary(DelayComponent):
             floatParameter(
                 name="PBDOT",
                 units=u.day / u.day,
-                description="Orbital period derivitve respect to time",
+                description="Orbital period derivative respect to time",
                 unit_scale=True,
                 scale_factor=1e-12,
                 scale_threshold=1e-7,
@@ -108,7 +113,7 @@ class PulsarBinary(DelayComponent):
             floatParameter(
                 name="EDOT",
                 units="1/s",
-                description="Eccentricity derivitve respect to time",
+                description="Eccentricity derivative respect to time",
                 unit_scale=True,
                 scale_factor=1e-12,
                 scale_threshold=1e-7,
@@ -139,7 +144,7 @@ class PulsarBinary(DelayComponent):
             floatParameter(
                 name="M2",
                 units=u.M_sun,
-                description="Mass of companian in the unit Sun mass",
+                description="Mass of companion in the unit Sun mass",
             )
         )
         self.add_param(
@@ -271,10 +276,15 @@ class PulsarBinary(DelayComponent):
             the standard barycentering. The stand alone binary receives the
             input TOAs - acc_delay.
 
+        Notes
+        -----
+        The values for ``obs_pos`` (the observatory position wrt the Solar System Barycenter) and ``psr_pos``
+        (the pulsar position wrt the Solar System Barycenter) are both computed in the same reference frame, ICRS or ECL depending on the model.
+
         Warns
         -----
         If passing 'None' to 'toa' argument, the stand alone binary model will use
-        the TOAs were passed to it from last interation (i.e. last barycnetered
+        the TOAs were passed to it from last iteration (i.e. last barycentered
         TOAs) or no TOAs for stand alone binary model at all. This behavior will
         cause incorrect answers. Allowing the passing None to 'toa' argument is
         for some lower level functions and tests. We do not recommend PINT
@@ -282,7 +292,7 @@ class PulsarBinary(DelayComponent):
         """
         # Don't need to fill P0 and P1. Translate all the others to the format
         # that is used in bmodel.py
-        # Get barycnetric toa first
+        # Get barycentric toa first
         updates = {}
         if toas is not None:
             tbl = toas.table
@@ -293,10 +303,25 @@ class PulsarBinary(DelayComponent):
             else:
                 self.barycentric_time = tbl["tdbld"] * u.day - acc_delay
             updates["barycentric_toa"] = self.barycentric_time
-            updates["obs_pos"] = tbl["ssb_obs_pos"].quantity
-            updates["psr_pos"] = self._parent.ssb_to_psb_xyz_ICRS(
-                epoch=tbl["tdbld"].astype(np.float64)
-            )
+            if "AstrometryEquatorial" in self._parent.components:
+                # it's already in ICRS
+                updates["obs_pos"] = tbl["ssb_obs_pos"].quantity
+                updates["psr_pos"] = self._parent.ssb_to_psb_xyz_ICRS(
+                    epoch=tbl["tdbld"].astype(np.float64)
+                )
+            elif "AstrometryEcliptic" in self._parent.components:
+                # convert from ICRS to ECL
+                obs_pos = SkyCoord(
+                    tbl["ssb_obs_pos"].quantity,
+                    representation_type="cartesian",
+                    frame="icrs",
+                )
+                updates["obs_pos"] = obs_pos.transform_to(
+                    PulsarEcliptic(ecl=self._parent.ECL.value)
+                ).cartesian.xyz.transpose()
+                updates["psr_pos"] = self._parent.ssb_to_psb_xyz_ECL(
+                    epoch=tbl["tdbld"].astype(np.float64), ecl=self._parent.ECL.value
+                )
         for par in self.binary_instance.binary_params:
             if par in self.binary_instance.param_aliases.keys():
                 alias = self.binary_instance.param_aliases[par]
@@ -335,7 +360,7 @@ class PulsarBinary(DelayComponent):
         return self.binary_instance.binary_delay()
 
     def d_binary_delay_d_xxxx(self, toas, param, acc_delay):
-        """Return the binary model delay derivtives."""
+        """Return the binary model delay derivatives."""
         self.update_binary_object(toas, acc_delay)
         return self.binary_instance.d_binarydelay_d_par(param)
 
@@ -368,7 +393,7 @@ class PulsarBinary(DelayComponent):
 
         T0 will be changed to the periapsis time closest to the supplied epoch,
         and the argument of periapsis (OM), eccentricity (ECC), and projected
-        semimajor axis (A1 or X) will be updated according to the specified
+        semi-major axis (A1 or X) will be updated according to the specified
         OMDOT, EDOT, and A1DOT or XDOT, if present.
 
         Note that derivatives of binary orbital frequency higher than the first
@@ -399,18 +424,18 @@ class PulsarBinary(DelayComponent):
         else:
             PB = 1.0 / self.FB0.quantity
             try:
-                PBDOT = -self.FB1.quantity / self.FB0.quantity ** 2
+                PBDOT = -self.FB1.quantity / self.FB0.quantity**2
             except AttributeError:
                 PBDOT = 0.0 * u.Unit("")
 
         # Find closest periapsis time and reassign T0
         t0_ld = self.T0.quantity.tdb.mjd_long
         dt = (new_epoch.tdb.mjd_long - t0_ld) * u.day
-        d_orbits = dt / PB - PBDOT * dt ** 2 / (2.0 * PB ** 2)
+        d_orbits = dt / PB - PBDOT * dt**2 / (2.0 * PB**2)
         n_orbits = np.round(d_orbits.to(u.Unit("")))
         if n_orbits == 0:
             return
-        dt_integer_orbits = PB * n_orbits + PB * PBDOT * n_orbits ** 2 / 2.0
+        dt_integer_orbits = PB * n_orbits + PB * PBDOT * n_orbits**2 / 2.0
         self.T0.quantity = self.T0.quantity + dt_integer_orbits
 
         try:
