@@ -2,8 +2,6 @@ import astropy.constants as c
 import astropy.units as u
 import numpy as np
 
-from pint import GMsun, Tsun, ls
-
 from .binary_generic import PSR_BINARY
 
 
@@ -81,7 +79,7 @@ class BTmodel(PSR_BINARY):
     """
 
     def __init__(self, t=None, input_params=None):
-        super(BTmodel, self).__init__()
+        super().__init__()
         self.binary_name = "BT"
         self.binary_params = list(self.param_default_value.keys())
         self.set_param_values()  # Set parameters to default values.
@@ -131,7 +129,7 @@ class BTmodel(PSR_BINARY):
         omega = self.omega()
         ecc = self.ecc()
         E = self.E()
-        num = a1 * np.cos(omega) * np.sqrt(1 - ecc ** 2) * np.cos(E) - a1 * np.sin(
+        num = a1 * np.cos(omega) * np.sqrt(1 - ecc**2) * np.cos(E) - a1 * np.sin(
             omega
         ) * np.sin(E)
         den = 1.0 - ecc * np.cos(E)
