@@ -1,21 +1,15 @@
 """Delay due to Earth's troposphere"""
-import logging
-from warnings import warn
-
 import astropy.constants as const
 import astropy.units as u
 import numpy as np
 import scipy.interpolate
 from astropy.coordinates import AltAz, SkyCoord
+from loguru import logger as log
 
-import pint.utils as ut
 from pint.models.parameter import boolParameter
 from pint.models.timing_model import DelayComponent
 from pint.observatory import get_observatory
 from pint.observatory.topo_obs import TopoObs
-from pint.toa_select import TOASelect
-
-log = logging.getLogger(__name__)
 
 
 class TroposphereDelay(DelayComponent):
@@ -34,7 +28,7 @@ class TroposphereDelay(DelayComponent):
     The hydrostatic delay is best described as the relatively non-changing component to the
     delay, depending primarily on atmospheric pressure.
     The wet delay represents changes due to dynamical variation in the
-    atmosphere (ie changing water vapor) and is ususally around 10% of the hydrostatic delay
+    atmosphere (ie changing water vapor) and is usually around 10% of the hydrostatic delay
 
     Parameters supported:
 
@@ -93,7 +87,7 @@ class TroposphereDelay(DelayComponent):
         """equation 4 from the Niell mapping function.
         It is a modification to the plane-parallel atmosphere model (1 / sin(alt))
         The coefficients a b and c provide the correction for the correct map
-        near the horizion, while still producing the correct mapping at zenith (1)
+        near the horizon, while still producing the correct mapping at zenith (1)
         """
         sinAlt = np.sin(alt)
         return 1 / (
@@ -130,15 +124,13 @@ class TroposphereDelay(DelayComponent):
             array[-1] = array[-2]
 
     def _get_target_altitude(self, obs, grp, radec):
-        """convert the sky coordinates of the target to the angular altitude at each TOA
-        """
+        """convert the sky coordinates of the target to the angular altitude at each TOA"""
         transformAltaz = AltAz(location=obs, obstime=grp["mjd"])
         alt = radec.transform_to(transformAltaz).alt  # * u.deg
         return alt
 
     def _get_target_skycoord(self):
-        """return the sky coordinates for the target, either from equatorial or ecliptic coordinates
-        """
+        """return the sky coordinates for the target, either from equatorial or ecliptic coordinates"""
         try:
             radec = SkyCoord(
                 self._parent.RAJ.value * self._parent.RAJ.units,
@@ -155,7 +147,7 @@ class TroposphereDelay(DelayComponent):
     def troposphere_delay(self, toas, acc_delay=None):
         """This is the main function for the troposphere delay.
         Pass in the TOAs and it will calculate the delay for each TOA,
-        accounting for the observatory locaiton, target coordiantes, and time of observation
+        accounting for the observatory location, target coordinates, and time of observation
         """
         tbl = toas.table
         delay = np.zeros(len(tbl))
@@ -167,10 +159,8 @@ class TroposphereDelay(DelayComponent):
 
             # the only python for loop is to iterate through the unique observatory locations
             # all other math is computed through numpy
-            for ii, key in enumerate(tbl.groups.keys):
-                grp = tbl.groups[ii]
-                loind, hiind = tbl.groups.indices[ii : ii + 2]
-                obsobj = get_observatory(tbl.groups.keys[ii]["obs"])
+            for key, grp in toas.get_obs_groups():
+                obsobj = get_observatory(key)
 
                 # exclude non topocentric observations
                 if not isinstance(obsobj, TopoObs):
@@ -182,12 +172,12 @@ class TroposphereDelay(DelayComponent):
 
                 obs = obsobj.earth_location_itrf()
 
-                alt = self._get_target_altitude(obs, grp, radec)
+                alt = self._get_target_altitude(obs, tbl[grp], radec)
 
                 # now actually calculate the atmospheric delay based on the models
 
-                delay[loind:hiind] = self.delay_model(
-                    alt, obs.lat, obs.height, grp["tdbld"]
+                delay[grp] = self.delay_model(
+                    alt, obs.lat, obs.height, tbl[grp]["tdbld"]
                 )
         return delay * u.s
 
@@ -201,8 +191,8 @@ class TroposphereDelay(DelayComponent):
         Then, to allow for fast numpy math, correct the individual invalid TOAs
         to make them appear at the zenith, then afterwards make that part of
         the delay be zero.
-        This alitude correction is applied to the alt numpy array passed in as argument
-        optionally pass obs to list which observatory the invalid altitues are from
+        This altitude correction is applied to the alt numpy array passed in as argument
+        optionally pass obs to list which observatory the invalid altitudes are from
 
         This has been tested and it does work, even though it's slightly convoluted
         """
@@ -222,16 +212,15 @@ class TroposphereDelay(DelayComponent):
 
             # now correct the values
             # first make the invalid altitudes zeros
-            alt *= isValid  # multilpy valids by 1, else make zero
+            alt *= isValid  # multiply valids by 1, else make zero
             alt += (
                 90 * u.deg * np.logical_not(isValid)
             )  # increase the invalid ones to 90 deg (zenith)
-            # this will prevent unexpected behaviour from occuring for negative altitudes
+            # this will prevent unexpected behavior from occurring for negative altitudes
         return isValid
 
     def delay_model(self, alt, lat, H, mjd):
-        """validate the observed altitudes, then combine dry and wet delays
-        """
+        """validate the observed altitudes, then combine dry and wet delays"""
         # make sure the altitudes are reasonable values, warn if not
         altIsValid = self._validate_altitudes(alt)
 
@@ -239,32 +228,29 @@ class TroposphereDelay(DelayComponent):
             alt, lat, H, mjd
         ) + self.wet_zenith_delay() * self.wet_map(alt, lat)
 
-        # modify the delay if any of the alittudes are invalid
+        # modify the delay if any of the altitudes are invalid
         if not np.all(altIsValid):
             delay *= altIsValid  # this will make the invalid delays zero
         return delay
 
     def pressure_from_altitude(self, H):
-        """From CRC Handbook Chapter 14 page 19 US Standard Atmosphere
-        """
+        """From CRC Handbook Chapter 14 page 19 US Standard Atmosphere"""
         gph = self.EARTH_R * H / (self.EARTH_R + H)  # geopotential height
         if gph > 11 * u.km:
-            warn("Pressure approximation invalid for elevations above 11 km")
+            log.warning("Pressure approximation invalid for elevations above 11 km")
         T = 288.15 - 0.0065 * H.to(u.m).value  # temperature lapse
         P = 101.325 * (288.15 / T) ** -5.25575 * u.kPa
         return P
 
     def zenith_delay(self, lat, H):
-        """Calculate the hydrostatic zenith delay
-        """
+        """Calculate the hydrostatic zenith delay"""
         p = self.pressure_from_altitude(H)
         return (p / (43.921 * u.kPa)) / (
             const.c.value * (1 - 0.00266 * np.cos(2 * lat) - 0.00028 * H.value)
         )
 
     def wet_zenith_delay(self):
-        """ calculate the wet delay at zenith
-        """
+        """calculate the wet delay at zenith"""
         return 0.0  # this method will be updated in the future to
         # either allow explicit specification of the wet zenith delay
         # or approximate it from weather data
@@ -286,14 +272,13 @@ class TroposphereDelay(DelayComponent):
         raise ValueError("Invaid latitude: %s must be between -90 and 90 degrees" % lat)
 
     def mapping_function(self, alt, lat, H, mjd):
-        """this implements the Niell mapping function for hydrostatic delays
-        """
+        """this implements the Niell mapping function for hydrostatic delays"""
 
         yearFraction = self._get_year_fraction_fast(mjd, lat)
         """
         according to Niell, the way to use latitude interpolation is to interpolate
         between the nearest definite latitude coefficient functions.  So that means
-        I need to calcualte the function, then I can go back and interpolate between the results.
+        I need to calculate the function, then I can go back and interpolate between the results.
         I figure the easiest way to do this will be to calculate the function on the entire array
         """
 
@@ -344,7 +329,7 @@ class TroposphereDelay(DelayComponent):
         to be predictable from the station height"
         """
 
-        latIndex = self._find_latitude_index(lat)  # lattitude dependent
+        latIndex = self._find_latitude_index(lat)  # latitude dependent
 
         aNeighbors = self.AW[latIndex : latIndex + 2]
         bNeighbors = self.BW[latIndex : latIndex + 2]
@@ -360,7 +345,7 @@ class TroposphereDelay(DelayComponent):
 
     @staticmethod
     def _interp(x, xn, yn):
-        """ vectorized 1d interpolation for 2 points only"""
+        """vectorized 1d interpolation for 2 points only"""
         # return (x - xn[0]) * (yn[1] - yn[0]) / (xn[1] - xn[0]) + yn[0]
         f = scipy.interpolate.interp1d(xn, yn)
         return f(x)
