@@ -8,6 +8,7 @@ from collections import OrderedDict
 from warnings import warn
 import copy
 
+import pint.utils as pu
 
 __all__ = [
     "PintMatrix",
@@ -86,7 +87,7 @@ class PintMatrix:
         Parameters
         ----------
         k: int (optional)
-            Diagonal in question. The default is 0. Use k>0 for diagonals above the main diagonal, and k<0 for diagonals below the main diagonal.            
+            Diagonal in question. The default is 0. Use k>0 for diagonals above the main diagonal, and k<0 for diagonals below the main diagonal.
 
         Returns
         -------
@@ -342,7 +343,7 @@ class DesignMatrix(PintMatrix):
     """
 
     def __init__(self, matrix, labels):
-        super(DesignMatrix, self).__init__(matrix, labels)
+        super().__init__(matrix, labels)
 
     @property
     def param_units(self):
@@ -435,7 +436,7 @@ class DesignMatrixMaker:
 
 
 class PhaseDesignMatrixMaker(DesignMatrixMaker):
-    """A specific class for makeing phase design matrix."""
+    """A specific class for making phase design matrix."""
 
     def __call__(self, data, model, derivative_params, offset=True, offset_padding=1.0):
         """Create the phase design matrix.
@@ -598,7 +599,7 @@ def combine_design_matrices_by_param(matrix1, matrix2, padding=0.0):
     # init the quantity axis.
     axis_labels = copy.deepcopy(matrix1.axis_labels)
 
-    # Get the base matrix labels and indcies.
+    # Get the base matrix labels and indices.
     base_params = matrix1.derivative_params
     base_quantity_index = matrix1.axis_labels[0]
 
@@ -606,8 +607,7 @@ def combine_design_matrices_by_param(matrix1, matrix2, padding=0.0):
     for d_param in matrix2.derivative_params:
         if d_param in base_params:
             raise ValueError(
-                "Input design matrix {} has duplicated "
-                "parameters with matrix {}".format(ii, 0)
+                f"Unable to combine the two design matrices as they have duplicated parameter(s): '{d_param}'."
             )
     # check if input design matrix has same quantity and padding.
     new_quantity_index = {}
@@ -652,7 +652,7 @@ def combine_design_matrices_by_param(matrix1, matrix2, padding=0.0):
         )
 
     # Combine matrix
-    # make default new matrix with the rigth size
+    # make default new matrix with the right size
     new_matrix = np.zeros((base_matrix.shape[0], matrix2.shape[1]))
     new_matrix.fill(padding)
     # Fill up the new_matrix with matrix2
@@ -688,9 +688,31 @@ class CovarianceMatrix(PintMatrix):
         # Check if the labels are symmetric
         if len(labels[0]) != len(labels[1]):
             raise ValueError("The input labels are not symmetric.")
-        super(CovarianceMatrix, self).__init__(matrix, labels)
+        super().__init__(matrix, labels)
 
-    def prettyprint(self, prec=3, coordinatefirst=False):
+    def _colorize_from_value(self, x, base):
+        """Return color setting/un-setting codes
+
+        Parameters
+        ----------
+        x : float
+            the value of the parameter from the correlation matrix, +/-(0-1)
+        base : string
+            the base text that will be formatted and colorized
+        """
+        absx = abs(x)
+        if absx < 0.5:
+            return base  # default terminal text color
+        elif absx < 0.9:
+            return pu.colorize(base, "green")
+        elif absx < 0.99:
+            return pu.colorize(base, "yellow")
+        elif absx < 0.999:
+            return pu.colorize(base, "red")
+        else:
+            return pu.colorize(base, "red", attribute="reverse")
+
+    def prettyprint(self, prec=3, coordinatefirst=False, offset=False, usecolor=True):
         """
         Return a version of the array formatted for printing (with labels etc).
 
@@ -700,6 +722,10 @@ class CovarianceMatrix(PintMatrix):
             precision of floating-point output
         coordinatefirst : bool, optional
             whether or not the output should be re-ordered to put the coordinates first (after the Offset, if present)
+        offset : bool, optional
+            whether the absolute phase (i.e. "offset") should be shown
+        usecolor : bool, optional
+            use color for "problem" CorrelationMatrix params
 
         Return
         ------
@@ -711,10 +737,7 @@ class CovarianceMatrix(PintMatrix):
         if coordinatefirst:
             # reorder so that RAJ/DECJ (or other coordinate pairs?) are first in the output
             # but actually include the phase zero-point first if it's there
-            if "Offset" in fps:
-                offsetfirst = True
-            else:
-                offsetfirst = False
+            offsetfirst = "Offset" in fps
             if ("RAJ" in fps) and ("DECJ" in fps):
                 coordinates = ["RAJ", "DECJ"]
             elif ("ELONG" in fps) and ("ELAT" in fps):
@@ -746,7 +769,15 @@ class CovarianceMatrix(PintMatrix):
                 cm = self.matrix
         else:
             cm = self.matrix
-        lens = [max(len(fp) + 2, prec + 8) for fp in fps]
+        if offset == False:
+            nfps = fps.remove("Offset")
+            cm = self.get_label_matrix(fps).matrix
+        if self.matrix_type == "covariance":
+            base = "{0: {width}.{prec}e}"
+            lens = [max(len(fp) + 2, prec + 8) for fp in fps]
+        else:  # "correlation"
+            base = "{0: {width}.{prec}f}"
+            lens = [max(len(fp) + 2, prec + 4) for fp in fps]
         maxlen = max(lens)
         sout = "\nParameter {} matrix:\n".format(self.matrix_type)
         line = "{0:^{width}}".format("", width=maxlen)
@@ -756,7 +787,13 @@ class CovarianceMatrix(PintMatrix):
         for ii, fp1 in enumerate(fps):
             line = "{0:^{width}}".format(fp1, width=maxlen)
             for jj, (fp2, ln) in enumerate(zip(fps[: ii + 1], lens[: ii + 1])):
-                line += "{0: {width}.{prec}e}".format(cm[ii, jj], width=ln, prec=prec)
+                x = cm[ii, jj]
+                text = (
+                    self._colorize_from_value(x, base)
+                    if usecolor and ii != jj
+                    else base
+                )
+                line += text.format(x, width=ln, prec=prec)
             sout += line + "\n"
         sout += "\n"
         return sout
@@ -817,7 +854,7 @@ class CovarianceMatrixMaker:
         func = getattr(model, self.cov_func_name)
         M = func(data)
         label = [
-            {self.covariance_quantity: (0, M.shape[0], self.quantity_unit ** 2)}
+            {self.covariance_quantity: (0, M.shape[0], self.quantity_unit**2)}
         ] * 2
         return CovarianceMatrix(M, label)
 
