@@ -1,13 +1,14 @@
-import copy
-import os
-import tempfile
+import io
 
 import tkinter as tk
 import tkinter.filedialog as tkFileDialog
-import tkinter.messagebox as tkMessageBox
 
 import pint.models
 
+import pint.logging
+from loguru import logger as log
+import pint.pintk.plk
+
 
 class ParChoiceWidget(tk.Frame):
     """
@@ -17,6 +18,7 @@ class ParChoiceWidget(tk.Frame):
 
     def __init__(self, master=None):
         tk.Frame.__init__(self, master)
+        self.configure(bg=pint.pintk.plk.background)
 
         self.choose_callback = None
         self.initLayout()
@@ -29,6 +31,8 @@ class ParChoiceWidget(tk.Frame):
             command=self.choose,
             variable=self.choice,
             value="prefit",
+            bg=pint.pintk.plk.background,
+            fg=pint.pintk.plk.foreground,
         )
         self.prefit.select()
         self.prefit.grid(row=0, column=0)
@@ -39,6 +43,8 @@ class ParChoiceWidget(tk.Frame):
             command=self.choose,
             variable=self.choice,
             value="postfit",
+            bg=pint.pintk.plk.background,
+            fg=pint.pintk.plk.foreground,
         )
         self.postfit.grid(row=0, column=1)
 
@@ -56,6 +62,7 @@ class ParActionsWidget(tk.Frame):
 
     def __init__(self, master=None):
         tk.Frame.__init__(self, master)
+        self.configure(bg=pint.pintk.plk.background)
 
         self.reset_callback = None
         self.remove_callback = None
@@ -68,25 +75,60 @@ class ParActionsWidget(tk.Frame):
         self.initLayout()
 
     def initLayout(self):
-        button = tk.Button(self, text="Reset Model", command=self.resetParfile)
+        button = tk.Button(
+            self,
+            text="Reset Model",
+            command=self.resetParfile,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=0, column=0)
 
-        button = tk.Button(self, text="Remove Changes", command=self.removeChanges)
+        button = tk.Button(
+            self,
+            text="Remove Changes",
+            command=self.removeChanges,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=0, column=1)
 
-        button = tk.Button(self, text="Apply Changes", command=self.applyChanges)
+        button = tk.Button(
+            self,
+            text="Apply Changes",
+            command=self.applyChanges,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=0, column=2)
 
-        button = tk.Button(self, text="Write Par", command=self.writePar)
+        button = tk.Button(
+            self,
+            text="Write Par",
+            command=self.writePar,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=0, column=3)
 
-        button = tk.Button(self, text="Center PEPOCH", command=self.centerPEPOCH)
+        button = tk.Button(
+            self,
+            text="Center PEPOCH",
+            command=self.centerPEPOCH,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=0, column=4)
 
-        button = tk.Button(self, text="Center POSEPOCH", command=self.centerPOSEPOCH)
+        button = tk.Button(
+            self,
+            text="Center POSEPOCH",
+            command=self.centerPOSEPOCH,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=1, column=1)
 
-        button = tk.Button(self, text="Center T0", command=self.centerT0)
+        button = tk.Button(
+            self,
+            text="Center T0",
+            command=self.centerT0,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=1, column=2)
 
     def setCallbacks(
@@ -108,39 +150,39 @@ class ParActionsWidget(tk.Frame):
         self.centerT0_callback = centerT0
 
     def resetParfile(self):
+        log.debug("Reset clicked")
         if self.reset_callback is not None:
             self.reset_callback()
-        print("Reset clicked")
 
     def removeChanges(self):
+        log.debug("Remove clicked")
         if self.remove_callback is not None:
             self.remove_callback()
-        print("Remove clicked")
 
     def applyChanges(self):
+        log.debug("Apply clicked")
         if self.apply_callback is not None:
             self.apply_callback()
-        print("Apply clicked")
 
     def writePar(self):
+        log.debug("Write clicked")
         if self.write_callback is not None:
             self.write_callback()
-        print("Write clicked")
 
     def centerPEPOCH(self):
+        log.debug("Center PEPOCH clicked")
         if self.centerPE_callback is not None:
             self.centerPE_callback()
-        print("Center PEPOCH clicked")
 
     def centerPOSEPOCH(self):
+        log.debug("Center POSEPOCH clicked")
         if self.centerPO_callback is not None:
             self.centerPO_callback()
-        print("Center POSEPOCH clicked")
 
     def centerT0(self):
+        log.debug("Center T0 clicked")
         if self.centerT0_callback is not None:
             self.centerT0_callback()
-        print("Center T0 clicked")
 
 
 class ParWidget(tk.Frame):
@@ -150,6 +192,7 @@ class ParWidget(tk.Frame):
 
     def __init__(self, master=None):
         tk.Frame.__init__(self, master)
+        self.configure(bg=pint.pintk.plk.background)
 
         self.psr = None
         self.update_callbacks = None
@@ -210,22 +253,18 @@ class ParWidget(tk.Frame):
                 self.editor.delete("1.0", tk.END)
                 self.editor.insert("1.0", self.psr.postfit_model.as_parfile())
             else:
-                print("There is no postfit model yet!")
+                log.warning("There is no postfit model yet!")
                 self.choiceWidget.prefit.select()
         elif choice == "prefit":
             self.editor.delete("1.0", tk.END)
             self.editor.insert("1.0", self.psr.prefit_model.as_parfile())
 
     def applyChanges(self):
-        pfilename = tempfile.mkstemp()[1]
-        pfile = open(pfilename, "w")
-        pfile.write(self.editor.get("1.0", "end-1c"))
-        pfile.close()
+        text = self.editor.get("1.0", "end-1c")
         if self.psr.fitted:
             # if pulsar already fitted, add changes to postfit model as well
-            self.psr.postfit_model = pint.models.get_model(pfilename)
-        self.psr.prefit_model = pint.models.get_model(pfilename)
-        os.remove(pfilename)
+            self.psr.postfit_model = pint.models.get_model(io.StringIO(text))
+        self.psr.prefit_model = pint.models.get_model(io.StringIO(text))
         self.call_updates()
 
     def writePar(self):
@@ -234,16 +273,16 @@ class ParWidget(tk.Frame):
             fout = open(filename, "w")
             fout.write(self.editor.get("1.0", "end-1c"))
             fout.close()
-            print("Saved parfile to %s" % filename)
+            log.info("Saved parfile to %s" % filename)
         except:
             if filename == () or filename == "":
-                print("Write Par cancelled.")
+                log.warning("Write Par cancelled.")
             else:
-                print("Could not save parfile to filename:\t%s" % filename)
+                log.warning("Could not save parfile to filename:\t%s" % filename)
 
     def centerPEPOCH(self):
         if not hasattr(self.psr.prefit_model, "PEPOCH"):
-            print("No PEPOCH to center.")
+            log.warning("No PEPOCH to center.")
             return
         mintime, maxtime = (
             self.psr.all_toas.get_mjds().min(),
@@ -258,7 +297,7 @@ class ParWidget(tk.Frame):
 
     def centerPOSEPOCH(self):
         if not hasattr(self.psr.prefit_model, "POSEPOCH"):
-            print("No POSEPOCH to center.")
+            log.warning("No POSEPOCH to center.")
             return
         mintime, maxtime = (
             self.psr.all_toas.get_mjds().min(),
@@ -273,7 +312,7 @@ class ParWidget(tk.Frame):
 
     def centerT0(self):
         if not hasattr(self.psr.prefit_model, "T0"):
-            print("No T0 to center.")
+            log.warning("No T0 to center.")
             return
         mintime, maxtime = (
             self.psr.all_toas.get_mjds().min(),
