@@ -1,14 +1,15 @@
-import copy
-import os
-import tempfile
+import io
 
 import astropy.time
 import tkinter as tk
 import tkinter.filedialog as tkFileDialog
-import tkinter.messagebox as tkMessageBox
 
 import pint
 
+import pint.logging
+from loguru import logger as log
+import pint.pintk.plk
+
 
 class TimActionsWidget(tk.Frame):
     """
@@ -17,6 +18,8 @@ class TimActionsWidget(tk.Frame):
 
     def __init__(self, master=None):
         tk.Frame.__init__(self, master)
+        self.configure(bg=pint.pintk.plk.background)
+
         self.reset_callback = None
         self.remove_callback = None
         self.apply_callback = None
@@ -25,16 +28,40 @@ class TimActionsWidget(tk.Frame):
         self.initLayout()
 
     def initLayout(self):
-        button = tk.Button(self, text="Reset TOAs", command=self.resetTimfile)
+        button = tk.Button(
+            self,
+            text="Reset TOAs",
+            command=self.resetTimfile,
+            bg=pint.pintk.plk.background,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=0, column=0)
 
-        button = tk.Button(self, text="Remove Changes", command=self.removeChanges)
+        button = tk.Button(
+            self,
+            text="Remove Changes",
+            command=self.removeChanges,
+            bg=pint.pintk.plk.background,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=0, column=1)
 
-        button = tk.Button(self, text="Apply Changes", command=self.applyChanges)
+        button = tk.Button(
+            self,
+            text="Apply Changes",
+            command=self.applyChanges,
+            bg=pint.pintk.plk.background,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=0, column=2)
 
-        button = tk.Button(self, text="Write Tim", command=self.writeTim)
+        button = tk.Button(
+            self,
+            text="Write Tim",
+            command=self.writeTim,
+            bg=pint.pintk.plk.background,
+            fg=pint.pintk.plk.foreground,
+        )
         button.grid(row=0, column=3)
 
     def setCallbacks(self, resetTimfile, removeChanges, applyChanges, writeTim):
@@ -44,24 +71,24 @@ class TimActionsWidget(tk.Frame):
         self.write_callback = writeTim
 
     def resetTimfile(self):
+        log.debug("Reset clicked")
         if self.reset_callback is not None:
             self.reset_callback()
-        print("Reset clicked")
 
     def removeChanges(self):
+        log.debug("Remove clicked")
         if self.remove_callback is not None:
             self.remove_callback()
-        print("Remove clicked")
 
     def applyChanges(self):
+        log.debug("Apply clicked")
         if self.apply_callback is not None:
             self.apply_callback()
-        print("Apply clicked")
 
     def writeTim(self):
+        log.debug("Write clicked")
         if self.write_callback is not None:
             self.write_callback()
-        print("Write clicked")
 
 
 class TimWidget(tk.Frame):
@@ -71,6 +98,9 @@ class TimWidget(tk.Frame):
 
     def __init__(self, master=None):
         tk.Frame.__init__(self, master)
+        self.configure(
+            bg=pint.pintk.plk.background,
+        )
 
         self.psr = None
         self.update_callbacks = None
@@ -147,12 +177,8 @@ class TimWidget(tk.Frame):
         self.editor.insert("1.0", asfile)
 
     def applyChanges(self):
-        tfilename = tempfile.mkstemp()[1]
-        tfile = open(tfilename, "w")
-        tfile.write(self.editor.get("1.0", "end-1c"))
-        tfile.close()
-        self.psr.selected_toas = pint.toa.get_TOAs(tfilename)
-        os.remove(tfilename)
+        text = self.editor.get("1.0", "end-1c")
+        self.psr.selected_toas = pint.toa.get_TOAs(io.StringIO(text))
         self.call_updates()
 
     def writeTim(self):
@@ -161,9 +187,9 @@ class TimWidget(tk.Frame):
             fout = open(filename, "w")
             fout.write(self.editor.get("1.0", "end-1c"))
             fout.close()
-            print("Saved timfile to %s" % filename)
+            log.info("Saved timfile to %s" % filename)
         except:
             if filename == () or filename == "":
-                print("Write Tim cancelled.")
+                log.warning("Write Tim cancelled.")
             else:
-                print("Could not save timfile to filename:\t%s" % filename)
+                log.warning("Could not save timfile to filename:\t%s" % filename)
