@@ -1,19 +1,16 @@
 """Generate random models distributed like the results of a fit."""
 
-import logging
 from collections import OrderedDict
 from copy import deepcopy
 
 import numpy as np
+from loguru import logger as log
 
-import pint.toa as toa
 import pint.simulation as simulation
 from pint.phase import Phase
 
-log = logging.getLogger(__name__)
 
 __all__ = ["random_models"]
-# log.setLevel("INFO")
 
 
 def random_models(
@@ -39,7 +36,7 @@ def random_models(
     iter
         how many random models will be computed, default 1
     npoints
-        how many fake toas will be reated for the random lines, default 100
+        how many fake toas will be related for the random lines, default 100
 
     Returns
     -------
@@ -89,7 +86,7 @@ def random_models(
         # from calc_phase_resids in residuals
         rs -= Phase(0.0, rs2.frac.mean() - rs_mean)
         # TODO: use units here!
-        rs = ((rs.int + rs.frac).value / fitter.model.F0.value) * 10 ** 6
+        rs = ((rs.int + rs.frac).value / fitter.model.F0.value) * 10**6
         rss.append(rs)
         random_models.append(deepcopy(mrand))
 
