@@ -1,19 +1,21 @@
 import argparse
-import logging
 import os
 
+import pint.logging
+from loguru import logger as log
+
+pint.logging.setup(level=pint.logging.script_level)
+
 from pint.models import get_model
 from pint.models.parameter import _parfile_formats
 
-logging.basicConfig(level=logging.WARNING)
-log = logging.getLogger(__name__)
-
 __all__ = ["main"]
 
 
 def main(argv=None):
     parser = argparse.ArgumentParser(
-        description="PINT tool for command-line parfile format conversions"
+        description="PINT tool for command-line parfile format conversions",
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     parser.add_argument("input", help="Input parfile", type=str)
 
@@ -25,18 +27,30 @@ def main(argv=None):
         default="pint",
     )
     parser.add_argument(
-        "-o", "--out", help=("Output filename [default=stdout]"), default=None,
+        "-o",
+        "--out",
+        help=("Output filename [default=stdout]"),
+        default=None,
+    )
+    parser.add_argument(
+        "--log-level",
+        type=str,
+        choices=pint.logging.levels,
+        default=pint.logging.script_level,
+        help="Logging level",
+        dest="loglevel",
     )
     parser.add_argument(
         "-v", "--verbosity", default=0, action="count", help="Increase output verbosity"
     )
+    parser.add_argument(
+        "-q", "--quiet", default=0, action="count", help="Decrease output verbosity"
+    )
 
     args = parser.parse_args(argv)
-    if args.verbosity == 1:
-        log.setLevel("INFO")
-    elif args.verbosity >= 2:
-        log.setLevel("DEBUG")
-
+    pint.logging.setup(
+        level=pint.logging.get_level(args.loglevel, args.verbosity, args.quiet)
+    )
     if not os.path.exists(args.input):
         log.error(f"Cannot open '{args.input}' for reading")
         return
