@@ -1,16 +1,16 @@
 #!/usr/bin/env python -W ignore::FutureWarning -W ignore::UserWarning -W ignore::DeprecationWarning
 import argparse
-import logging
-import os
 import sys
 
-import astropy.table
-import astropy.units as u
 import matplotlib.pyplot as plt
 import numpy as np
 import scipy.optimize as op
 from astropy.coordinates import SkyCoord
 from scipy.stats import norm, uniform
+import pint.logging
+from loguru import logger as log
+
+pint.logging.setup(level=pint.logging.script_level)
 
 import pint.fermi_toas as fermi
 import pint.models
@@ -18,15 +18,9 @@ import pint.plot_utils as plot_utils
 import pint.toa as toa
 from pint.eventstats import hm, hmw
 from pint.fitter import Fitter
-from pint.models.priors import (
-    GaussianBoundedRV,
-    Prior,
-    UniformBoundedRV,
-    UniformUnboundedRV,
-)
+from pint.models.priors import Prior
 from pint.observatory.satellite_obs import get_satellite_observatory
 
-log = logging.getLogger(__name__)
 
 __all__ = ["read_gaussfitfile", "marginalize_over_phase", "main"]
 # log.setLevel('DEBUG')
@@ -42,7 +36,7 @@ class custom_timing(
     pint.models.spindown.Spindown, pint.models.astrometry.AstrometryEcliptic
 ):
     def __init__(self, parfile):
-        super(custom_timing, self).__init__()
+        super().__init__()
         self.read_parfile(parfile)
 
 
@@ -238,8 +232,7 @@ def marginalize_over_phase(
 
 
 def get_fit_keyvals(model, phs=0.0, phserr=0.1):
-    """Read the model to determine fitted keys and their values and errors from the par file
-    """
+    """Read the model to determine fitted keys and their values and errors from the par file"""
     fitkeys = [p for p in model.params if not getattr(model, p).frozen]
     fitvals = []
     fiterrs = []
@@ -258,7 +251,7 @@ class emcee_fitter(Fitter):
     def __init__(
         self, toas=None, model=None, template=None, weights=None, phs=0.5, phserr=0.03
     ):
-        # super(emcee_fitter, self).__init__(model=model, toas=toas)
+        # super().__init__(model=model, toas=toas)
         self.toas = toas
         self.model = model
         self.template = template
@@ -275,7 +268,7 @@ class emcee_fitter(Fitter):
         """
         Return pulse phases based on the current model
         """
-        phss = self.model.phase(self.toas)[1]
+        phss = self.model.phase(self.toas).frac
         return phss.value % 1
 
     def lnprior(self, theta):
@@ -342,7 +335,7 @@ class emcee_fitter(Fitter):
         """
         Make a nice 2-panel phaseogram for the current model
         """
-        mjds = self.toas.table["tdbld"].quantity
+        mjds = self.toas.table["tdbld"].data
         phss = self.get_event_phases()
         plot_utils.phaseogram(
             mjds,
@@ -428,7 +421,8 @@ class emcee_fitter(Fitter):
 def main(argv=None):
 
     parser = argparse.ArgumentParser(
-        description="PINT tool for MCMC optimization of timing models using event data."
+        description="PINT tool for MCMC optimization of timing models using event data.",
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
 
     parser.add_argument("eventfile", help="event file to use")
@@ -437,29 +431,29 @@ def main(argv=None):
     parser.add_argument("--ft2", help="Path to FT2 file.", default=None)
     parser.add_argument(
         "--weightcol",
-        help="name of weight column (or 'CALC' to have them computed",
+        help="name of weight column (or 'CALC' to have them computed)",
         default=None,
     )
     parser.add_argument(
-        "--nwalkers", help="Number of MCMC walkers (def 200)", type=int, default=200
+        "--nwalkers", help="Number of MCMC walkers", type=int, default=200
     )
     parser.add_argument(
         "--burnin",
-        help="Number of MCMC steps for burn in (def 100)",
+        help="Number of MCMC steps for burn in",
         type=int,
         default=100,
     )
     parser.add_argument(
         "--nsteps",
-        help="Number of MCMC steps to compute (def 1000)",
+        help="Number of MCMC steps to compute",
         type=int,
         default=1000,
     )
     parser.add_argument(
-        "--minMJD", help="Earliest MJD to use (def 54680)", type=float, default=54680.0
+        "--minMJD", help="Earliest MJD to use", type=float, default=54680.0
     )
     parser.add_argument(
-        "--maxMJD", help="Latest MJD to use (def 57250)", type=float, default=57250.0
+        "--maxMJD", help="Latest MJD to use", type=float, default=57250.0
     )
     parser.add_argument(
         "--phs", help="Starting phase offset [0-1] (def is to measure)", type=float
@@ -469,7 +463,7 @@ def main(argv=None):
     )
     parser.add_argument(
         "--minWeight",
-        help="Minimum weight to include (def 0.05)",
+        help="Minimum weight to include",
         type=float,
         default=0.05,
     )
@@ -509,10 +503,26 @@ def main(argv=None):
         default=False,
         action="store_true",
     )
-
-    global nwalkers, nsteps, ftr
+    parser.add_argument(
+        "--log-level",
+        type=str,
+        choices=pint.logging.levels,
+        default=pint.logging.script_level,
+        help="Logging level",
+        dest="loglevel",
+    )
+    parser.add_argument(
+        "-v", "--verbosity", default=0, action="count", help="Increase output verbosity"
+    )
+    parser.add_argument(
+        "-q", "--quiet", default=0, action="count", help="Decrease output verbosity"
+    )
 
     args = parser.parse_args(argv)
+    pint.logging.setup(
+        level=pint.logging.get_level(args.loglevel, args.verbosity, args.quiet)
+    )
+    global nwalkers, nsteps, ftr
 
     eventfile = args.eventfile
     parfile = args.parfile
@@ -586,11 +596,13 @@ def main(argv=None):
         ]
         log.info("There are %d events we will use" % len(tl))
         # Now convert to TOAs object and compute TDBs and posvels
-        ts = toa.TOAs(toalist=tl)
+        ts = toa.get_TOAs_list(tl, ephem="DE421", planets=False)
         ts.filename = eventfile
-        ts.compute_TDBs()
-        ts.compute_posvels(ephem="DE421", planets=False)
-        toa.save_pickle(ts)
+        # FIXME: writes to the TOA directory unconditionally
+        try:
+            toa.save_pickle(ts)
+        except IOError:
+            pass
 
     if weightcol is not None:
         if weightcol == "CALC":
