@@ -65,8 +65,25 @@ def main(argv=None):
         action="store_true",
         help="Use TT(BIPM) instead of TT(TAI)",
     )
+    parser.add_argument(
+        "--log-level",
+        type=str,
+        choices=pint.logging.levels,
+        default=pint.logging.script_level,
+        help="Logging level",
+        dest="loglevel",
+    )
+    parser.add_argument(
+        "-v", "--verbosity", default=0, action="count", help="Increase output verbosity"
+    )
+    parser.add_argument(
+        "-q", "--quiet", default=0, action="count", help="Decrease output verbosity"
+    )
 
     args = parser.parse_args(argv)
+    pint.logging.setup(
+        level=pint.logging.get_level(args.loglevel, args.verbosity, args.quiet)
+    )
 
     if args.format in ("mjd", "jd", "unix"):
         # These formats require conversion from string to long double first
@@ -101,7 +118,7 @@ def main(argv=None):
         # Should check if 12:13:14.2 syntax is used and support that as well!
         m.RAJ.quantity = Angle(args.ra)
         m.DECJ.quantity = Angle(args.dec)
-        m.DM.quantity = args.dm * u.parsec / u.cm ** 3
+        m.DM.quantity = args.dm * u.parsec / u.cm**3
 
     tdbtimes = m.get_barycentric_toas(ts)
 
