@@ -1,28 +1,29 @@
 #!/usr/bin/env python -W ignore::FutureWarning -W ignore::UserWarning -W ignore::DeprecationWarning
 """PINT-based tool for making simulated TOAs."""
-import logging
 
 import astropy.units as u
 import numpy as np
-from astropy.time import TimeDelta
+
+import pint.logging
+from loguru import logger as log
+
+pint.logging.setup(level=pint.logging.script_level)
 
 import pint.fitter
 import pint.models
-import pint.toa as toa
 import pint.simulation
 import pint.residuals
 
-log = logging.getLogger(__name__)
-
 __all__ = ["main"]
 
-# log.setLevel("INFO")
-
 
 def main(argv=None):
     import argparse
 
-    parser = argparse.ArgumentParser(description="PINT tool for simulating TOAs")
+    parser = argparse.ArgumentParser(
+        description="PINT tool for simulating TOAs",
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+    )
     parser.add_argument("parfile", help="par file to read model from")
     parser.add_argument("timfile", help="Output TOA file name")
     parser.add_argument(
@@ -33,7 +34,7 @@ def main(argv=None):
     )
     parser.add_argument(
         "--startMJD",
-        help="MJD of first fake TOA (default=56000.0)",
+        help="MJD of first fake TOA",
         type=float,
         default=56000.0,
     )
@@ -43,17 +44,17 @@ def main(argv=None):
     parser.add_argument(
         "--duration", help="Span of TOAs to generate (days)", type=float, default=400.0
     )
-    parser.add_argument("--obs", help="Observatory code (default: GBT)", default="GBT")
+    parser.add_argument("--obs", help="Observatory code", default="GBT")
     parser.add_argument(
         "--freq",
-        help="Frequency for TOAs (MHz) (default: 1400)",
+        help="Frequency for TOAs (MHz)",
         nargs="+",
         type=float,
         default=1400.0,
     )
     parser.add_argument(
         "--error",
-        help="Random error to apply to each TOA (us, default=1.0)",
+        help="Random error to apply to each TOA (us)",
         type=float,
         default=1.0,
     )
@@ -65,7 +66,7 @@ def main(argv=None):
     )
     parser.add_argument(
         "--fuzzdays",
-        help="Standard deviation of 'fuzz' distribution (jd) (default: 0.0)",
+        help="Standard deviation of 'fuzz' distribution (jd)",
         type=float,
         default=0.0,
     )
@@ -75,7 +76,25 @@ def main(argv=None):
     parser.add_argument(
         "--format", help="The format of out put .tim file.", default="TEMPO2"
     )
+    parser.add_argument(
+        "--log-level",
+        type=str,
+        choices=pint.logging.levels,
+        default=pint.logging.script_level,
+        help="Logging level",
+        dest="loglevel",
+    )
+    parser.add_argument(
+        "-v", "--verbosity", default=0, action="count", help="Increase output verbosity"
+    )
+    parser.add_argument(
+        "-q", "--quiet", default=0, action="count", help="Decrease output verbosity"
+    )
+
     args = parser.parse_args(argv)
+    pint.logging.setup(
+        level=pint.logging.get_level(args.loglevel, args.verbosity, args.quiet)
+    )
 
     log.info("Reading model from {0}".format(args.parfile))
     m = pint.models.get_model(args.parfile)
