@@ -31,28 +31,26 @@ has moved to :mod:`pint.simulation`.
 import configparser
 import datetime
 import getpass
-import logging
+import hashlib
 import os
 import platform
 import re
+import sys
 import textwrap
-from collections import OrderedDict
 from contextlib import contextmanager
-from copy import deepcopy
-from io import StringIO
+from pathlib import Path
 
 import astropy.constants as const
 import astropy.coordinates as coords
-import astropy.coordinates.angles as angles
+from astropy.time import Time
 import astropy.units as u
 import numpy as np
-import scipy.optimize.zeros as zeros
+from loguru import logger as log
 from scipy.special import fdtrc
 
 import pint
 import pint.pulsar_ecliptic
-
-log = logging.getLogger(__name__)
+from pint.toa_select import TOASelect
 
 __all__ = [
     "PosVel",
@@ -67,8 +65,8 @@ __all__ = [
     "open_or_use",
     "lines_of",
     "interesting_lines",
-    "show_param_cov_matrix",
     "pmtot",
+    "dmxselections",
     "dmxparse",
     "dmxstats",
     "dmx_ranges_old",
@@ -79,12 +77,60 @@ __all__ = [
     "add_dummy_distance",
     "remove_dummy_distance",
     "info_string",
+    "print_color_examples",
+    "colorize",
+    "group_iterator",
+    "compute_hash",
+    "PINTPrecisionError",
+    "check_longdouble_precision",
+    "require_longdouble_precision",
+    "get_conjunction",
+    "divide_times",
 ]
 
+COLOR_NAMES = ["black", "red", "green", "yellow", "blue", "magenta", "cyan", "white"]
+TEXT_ATTRIBUTES = [
+    "normal",
+    "bold",
+    "subdued",
+    "italic",
+    "underscore",
+    "blink",
+    "reverse",
+    "concealed",
+]
 
 # Actual exported tools
 
 
+class PINTPrecisionError(RuntimeError):
+    pass
+
+
+# A warning is emitted in pint.pulsar_mjd if sufficient precision is not available
+
+
+def check_longdouble_precision():
+    """Check whether long doubles have adequate precision.
+
+    Returns True if long doubles have enough precision to use PINT
+    for sub-microsecond timing on this machine.
+    """
+    return np.finfo(np.longdouble).eps < 2e-19
+
+
+def require_longdouble_precision():
+    """Raise an exception if long doubles do not have enough precision.
+
+    Raises RuntimeError if PINT cannot be run with high precision on this
+    machine.
+    """
+    if not check_longdouble_precision():
+        raise PINTPrecisionError(
+            f"PINT needs higher precision floating point than you have available. PINT uses the numpy longdouble type to represent modified Julian days, and this machine does not have sufficient numerical precision to represent sub-microsecond times with np.longdouble. On an M1 Mac you will need to use a Rosetta environment, or on a Windows machine you will need to us a different Python interpreter. Some PINT operations can work with reduced precision, but you have requested one that cannot."
+        )
+
+
 class PosVel:
     """Position/Velocity class.
 
@@ -95,7 +141,7 @@ class PosVel:
     and velocities respectively.
 
     The coordinates are generally assumed to be aligned with ICRF (J2000),
-    i.e. they are in an intertial, not earth-rotating frame
+    i.e. they are in an inertial, not earth-rotating frame
 
     The 'obj' and 'origin' components are strings that can optionally
     be used to specify names for endpoints of the vectors.  If present,
@@ -269,7 +315,7 @@ def has_astropy_unit(x):
 # Define prefix parameter pattern
 prefix_pattern = [
     re.compile(r"^([a-zA-Z]*\d+[a-zA-Z]+)(\d+)$"),  # For the prefix like T2EFAC2
-    re.compile(r"^([a-zA-Z]+)(\d+)$"),  # For the prefix like F12
+    re.compile(r"^([a-zA-Z]+)0*(\d+)$"),  # For the prefix like F12
     re.compile(r"^([a-zA-Z0-9]+_)(\d+)$"),  # For the prefix like DMXR1_3
     # re.compile(r'([a-zA-Z]\d[a-zA-Z]+)(\d+)'),  # for prefixes like PLANET_SHAPIRO2?
 ]
@@ -402,7 +448,7 @@ def open_or_use(f, mode="r"):
     a subclass of ``str`` will be passed through untouched.
 
     """
-    if isinstance(f, (str, bytes)):
+    if isinstance(f, (str, bytes, Path)):
         with open(f, mode) as fl:
             yield fl
     else:
@@ -453,77 +499,6 @@ def interesting_lines(lines, comments=None):
         yield ln
 
 
-def show_param_cov_matrix(matrix, params, name="Covariance Matrix", switchRD=False):
-    """function to print covariance matrices in a clean and easily readable way
-
-    :param matrix: matrix to be printed, should be square, list of lists
-    :param params: name of the parameters in the matrix, list
-    :param name: title to be printed above, default Covariance Matrix
-    :param switchRD: if True, switch the positions of RA and DEC to match setup of TEMPO cov. matrices
-
-    :return: string to be printed
-
-    Warning
-    -------
-    **DEPRECATED**.  Use :meth:`pint.pint_matrix.CovarianceMatrix.prettyprint` instead of :func:`show_param_cov_matrix`
-    """
-
-    warn(
-        "This method is deprecated. Use `parameter_covariance_matrix.prettyprint()` instead of `show_param_cov_matrix()`",
-        category=DeprecationWarning,
-    )
-
-    output = StringIO()
-    matrix = deepcopy(matrix)
-    try:
-        RAi = params.index("RAJ")
-    except:
-        RAi = None
-        switchRD = False
-    params1 = []
-    for param in params:
-        if len(param) < 3:
-            while len(param) != 3:
-                param = " " + param
-            params1.append(param)
-        elif len(param) > 3:
-            while len(param) != 3:
-                param = param[:-1]
-            params1.append(param)
-        else:
-            params1.append(param)
-    if switchRD:
-        # switch RA and DEC so cov matrix matches TEMPO
-        params1[RAi : RAi + 2] = [params1[RAi + 1], params1[RAi]]
-        i = 0
-        while i < 2:
-            RA = deepcopy(matrix[RAi])
-            matrix[RAi] = matrix[RAi + 1]
-            matrix[RAi + 1] = RA
-            matrix = matrix.T
-            i += 1
-    output.write(name + " switch RD = " + str(switchRD) + "\n")
-    output.write(" ")
-    for param in params1:
-        output.write("         " + param)
-    i = j = 0
-    while i < len(matrix):
-        output.write("\n" + params1[i] + " :: ")
-        while j <= i:
-            num = matrix[i][j]
-            if num < 0.001 and num > -0.001:
-                output.write("{0: 1.2e}".format(num) + "   : ")
-            else:
-                output.write("  " + "{0: 1.2f}".format(num) + "   : ")
-            j += 1
-        i += 1
-        j = 0
-    output.write("\b:\n")
-    contents = output.getvalue()
-    output.close()
-    return contents
-
-
 def pmtot(model):
     """Compute and return the total proper motion from a model object
 
@@ -550,11 +525,11 @@ def pmtot(model):
     """
 
     if "AstrometryEcliptic" in model.components.keys():
-        return np.sqrt(model.PMELONG.quantity ** 2 + model.PMELAT.quantity ** 2).to(
+        return np.sqrt(model.PMELONG.quantity**2 + model.PMELAT.quantity**2).to(
             u.mas / u.yr
         )
     elif "AstrometryEquatorial" in model.components.keys():
-        return np.sqrt(model.PMRA.quantity ** 2 + model.PMDEC.quantity ** 2).to(
+        return np.sqrt(model.PMRA.quantity**2 + model.PMDEC.quantity**2).to(
             u.mas / u.yr
         )
     else:
@@ -732,7 +707,7 @@ def dmx_ranges_old(
                 parameter_type="float",
                 name="DMX_{:04d}".format(ii + 1),
                 value=0.0,
-                units=u.pc / u.cm ** 3,
+                units=u.pc / u.cm**3,
                 frozen=False,
             )
             dmx_comp.add_param(dmx_par, setup=True)
@@ -843,7 +818,7 @@ def dmx_ranges(toas, divide_freq=1000.0 * u.MHz, binwidth=15.0 * u.d, verbose=Fa
                 parameter_type="float",
                 name="DMX_{:04d}".format(ii + 1),
                 value=0.0,
-                units=u.pc / u.cm ** 3,
+                units=u.pc / u.cm**3,
                 frozen=False,
             )
             dmx_comp.add_param(dmx_par, setup=True)
@@ -869,46 +844,71 @@ def dmx_ranges(toas, divide_freq=1000.0 * u.MHz, binwidth=15.0 * u.d, verbose=Fa
     return mask, dmx_comp
 
 
-def dmxstats(fitter):
-    """Run dmxparse in python using PINT objects and results.
+def dmxselections(model, toas):
+    """Map DMX selections to TOAs
+
+    Parameters
+    ----------
+    model : pint.models.TimingModel
+    toas : pint.toa.TOAs
+
+    Returns
+    -------
+    dict :
+        keys are DMX indices, values are the TOAs selected for each index
+    """
+    toas_selector = TOASelect(is_range=True)
+    DMX_mapping = model.get_prefix_mapping("DMX_")
+    DMXR1_mapping = model.get_prefix_mapping("DMXR1_")
+    DMXR2_mapping = model.get_prefix_mapping("DMXR2_")
+    condition = {}
+    for ii in DMX_mapping:
+        r1 = getattr(model, DMXR1_mapping[ii]).quantity
+        r2 = getattr(model, DMXR2_mapping[ii]).quantity
+        condition[DMX_mapping[ii]] = (r1.mjd, r2.mjd)
+    select_idx = toas_selector.get_select_index(condition, toas["mjd_float"])
+    return select_idx
+
+
+def dmxstats(model, toas, file=sys.stdout):
+    """Print DMX statistics
 
     Based off dmxparse by P. Demorest (https://github.com/nanograv/tempo/tree/master/util/dmxparse)
 
     Parameters
     ----------
-    fitter
-        PINT fitter used to get timing residuals, must have already run GLS fit
+    model : pint.models.TimingModel
+    toas : pint.toa.TOAs
+    file : a file-like object (stream); defaults to the current sys.stdout
     """
-
-    model = fitter.model
-    mjds = fitter.toas.get_mjds()
-    freqs = fitter.toas.table["freq"]
-    ii = 1
-    while hasattr(model, "DMX_{:04d}".format(ii)):
-        mmask = np.logical_and(
-            mjds.value > getattr(model, "DMXR1_{:04d}".format(ii)).value,
-            mjds.value < getattr(model, "DMXR2_{:04d}".format(ii)).value,
-        )
-        if np.any(mmask):
-            mjds_in_bin = mjds[mmask]
-            freqs_in_bin = freqs[mmask]
-            span = (mjds_in_bin.max() - mjds_in_bin.min()).to(u.d)
-            # Warning: min() and max() seem to strip the units
-            freqspan = freqs_in_bin.max() - freqs_in_bin.min()
+    mjds = toas.get_mjds()
+    freqs = toas.table["freq"]
+    selected = np.zeros(len(toas), dtype=np.bool8)
+    DMX_mapping = model.get_prefix_mapping("DMX_")
+    select_idx = dmxselections(model, toas)
+    for ii in DMX_mapping:
+        if f"DMX_{ii:04d}" in select_idx:
+            selection = select_idx[f"DMX_{ii:04d}"]
+            selected[selection] = True
             print(
                 "DMX_{:04d}: NTOAS={:5d}, MJDSpan={:14.4f}, FreqSpan={:8.3f}-{:8.3f}".format(
-                    ii, mmask.sum(), span, freqs_in_bin.min(), freqs_in_bin.max()
-                )
+                    ii,
+                    len(selection),
+                    (mjds[selection].max() - mjds[selection.min()]),
+                    freqs[selection].min() * u.MHz,
+                    freqs[selection].max() * u.MHz,
+                ),
+                file=file,
             )
         else:
             print(
                 "DMX_{:04d}: NTOAS={:5d}, MJDSpan={:14.4f}, FreqSpan={:8.3f}-{:8.3f}".format(
-                    ii, mmask.sum(), 0 * u.d, 0 * u.MHz, 0 * u.MHz
-                )
+                    ii, 0, 0 * u.d, 0 * u.MHz, 0 * u.MHz
+                ),
+                file=file,
             )
-        ii += 1
-
-    return
+    if not np.all(selected):
+        print(f"{(1-selected).sum()} TOAs not selected in any DMX window", file=file)
 
 
 def dmxparse(fitter, save=False):
@@ -919,69 +919,57 @@ def dmxparse(fitter, save=False):
     Parameters
     ----------
     fitter
-        PINT fitter used to get timing residuals, must have already run GLS fit
-    save : bool
-        if True saves output to text file in the format of the TEMPO version.
-        If not output save file is desired, save = False (which is the default)
-        Output file name is dmxparse.out
+        PINT fitter used to get timing residuals, must have already run a fit
+    save : bool or str or file-like object, optional
+        If not False or None, saves output to specified file in the format of the TEMPO version.  If ``True``, assumes output file is ``dmxparse.out``
 
     Returns
     -------
-    dictionary
+    dict :
 
-        dmxs : mean-subtraced dmx values
+        ``dmxs`` : mean-subtraced dmx values
 
-        dmx_verrs : dmx variance errors
+        ``dmx_verrs`` : dmx variance errors
 
-        dmxeps : center mjds of the dmx bins
+        ``dmxeps`` : center mjds of the dmx bins
 
-        r1s : lower mjd bounds on the dmx bins
+        ``r1s`` : lower mjd bounds on the dmx bins
 
-        r2s : upper mjd bounds on the dmx bins
+        ``r2s`` : upper mjd bounds on the dmx bins
 
-        bins : dmx bins
+        ``bins`` : dmx bins
 
-        mean_dmx : mean dmx value
+        ``mean_dmx`` : mean dmx value
 
-        avg_dm_err : uncertainty in average dmx
+        ``avg_dm_err`` : uncertainty in average dmx
 
     Raises
     ------
-    RuntimeError : If the model has no DMX parameters, or if there is a parsing problem
+    RuntimeError
+        If the model has no DMX parameters, or if there is a parsing problem
 
     """
     # We get the DMX values, errors, and mjds (same as in getting the DMX values for DMX v. time)
     # Get number of DMX epochs
-    dmx_epochs = []
-    for p in fitter.model.params:
-        if "DMX_" in p:
-            dmx_epochs.append(p.split("_")[-1])
-    # Check to make sure that there are DMX values in the model
-    if not dmx_epochs:
+    try:
+        DMX_mapping = fitter.model.get_prefix_mapping("DMX_")
+    except ValueError:
         raise RuntimeError("No DMX values in model!")
+    dmx_epochs = [f"{x:04d}" for x in DMX_mapping.keys()]
+    DMX_keys = list(DMX_mapping.values())
+    DMXs = np.zeros(len(dmx_epochs))
+    DMX_Errs = np.zeros(len(dmx_epochs))
+    DMX_R1 = np.zeros(len(dmx_epochs))
+    DMX_R2 = np.zeros(len(dmx_epochs))
+    mask_idxs = np.zeros(len(dmx_epochs), dtype=np.bool8)
     # Get DMX values (will be in units of 10^-3 pc cm^-3)
-    DMX_keys = []
-    DMXs = []
-    DMX_Errs = []
-    DMX_R1 = []
-    DMX_R2 = []
-    DMX_center_MJD = []
-    mask_idxs = []
-    for ii in dmx_epochs:
-        DMX_keys.append("DMX_{:}".format(ii))
-        DMXs.append(getattr(fitter.model, "DMX_{:}".format(ii)).value)
-        mask_idxs.append(getattr(fitter.model, "DMX_{:}".format(ii)).frozen)
-        DMX_Errs.append(getattr(fitter.model, "DMX_{:}".format(ii)).uncertainty_value)
-        dmxr1 = getattr(fitter.model, "DMXR1_{:}".format(ii)).value
-        dmxr2 = getattr(fitter.model, "DMXR2_{:}".format(ii)).value
-        DMX_R1.append(dmxr1)
-        DMX_R2.append(dmxr2)
-        DMX_center_MJD.append((dmxr1 + dmxr2) / 2)
-    DMXs = np.array(DMXs)
-    DMX_Errs = np.array(DMX_Errs)
-    DMX_R1 = np.array(DMX_R1)
-    DMX_R2 = np.array(DMX_R2)
-    DMX_center_MJD = np.array(DMX_center_MJD)
+    for ii, epoch in enumerate(dmx_epochs):
+        DMXs[ii] = getattr(fitter.model, "DMX_{:}".format(epoch)).value
+        mask_idxs[ii] = getattr(fitter.model, "DMX_{:}".format(epoch)).frozen
+        DMX_Errs[ii] = getattr(fitter.model, "DMX_{:}".format(epoch)).uncertainty_value
+        DMX_R1[ii] = getattr(fitter.model, "DMXR1_{:}".format(epoch)).value
+        DMX_R2[ii] = getattr(fitter.model, "DMXR2_{:}".format(epoch)).value
+    DMX_center_MJD = (DMX_R1 + DMX_R2) / 2
     # If any value need to be masked, do it
     if True in mask_idxs:
         log.warning(
@@ -1024,11 +1012,12 @@ def dmxparse(fitter, save=False):
         DMX_vErrs = DMX_Errs
     # Check we have the right number of params
     if len(DMXs) != len(DMX_Errs) or len(DMXs) != len(DMX_vErrs):
-        log.error("ERROR! Number of DMX entries do not match!")
         raise RuntimeError("Number of DMX entries do not match!")
 
     # Output the results'
-    if save:
+    if save is not None and save:
+        if isinstance(save, bool):
+            save = "dmxparse.out"
         DMX = "DMX"
         lines = []
         lines.append("# Mean %s value = %+.6e \n" % (DMX, DMX_mean))
@@ -1049,9 +1038,10 @@ def dmxparse(fitter, save=False):
                     DMX_keys[k],
                 )
             )
-        with open("dmxparse.out", "w") as dmxout:
+        with open_or_use(save, mode="w") as dmxout:
             dmxout.writelines(lines)
-            dmxout.close()
+            if isinstance(save, (str, Path)):
+                log.debug(f"Wrote dmxparse output to '{save}'")
     # return the new mean subtracted values
     mean_sub_DMXs = DMXs - DMX_mean
 
@@ -1073,6 +1063,124 @@ def dmxparse(fitter, save=False):
     return dmx
 
 
+def get_prefix_timerange(model, prefixname):
+    """Get time range for a prefix quantity like DMX or SWX
+
+    Parameters
+    ----------
+    model: pint.models.timing_model.TimingModel
+    prefixname : str
+        Something like ``DMX_0001`` or ``SWX_0005``
+
+    Returns
+    -------
+    tuple
+        Each element is astropy.time.Time
+
+    Example
+    -------
+    To match a range between SWX and DMX, you can do:
+
+        >>> m.add_DMX_range(*(59077.33674631197, 59441.34020807681), index=1, frozen=False)
+
+    Which sets ``DMX_0001`` to cover the same time range as ``SWX_0002``
+    """
+    prefix, index, indexnum = split_prefixed_name(prefixname)
+    r1 = prefix.replace("_", "R1_") + index
+    r2 = prefix.replace("_", "R2_") + index
+    return getattr(model, r1).quantity, getattr(model, r2).quantity
+
+
+def split_dmx(model, time):
+    """
+    Split an existing DMX bin at the desired time
+
+    Parameters
+    ----------
+    model : pint.models.timing_model.TimingModel
+    time : astropy.time.Time
+
+    Returns
+    -------
+    index : int
+        Index of existing bin that was split
+    newindex : int
+        Index of new bin that was added
+
+    """
+    try:
+        DMX_mapping = model.get_prefix_mapping("DMX_")
+    except ValueError:
+        raise RuntimeError("No DMX values in model!")
+    dmx_epochs = [f"{x:04d}" for x in DMX_mapping.keys()]
+    DMX_R1 = np.zeros(len(dmx_epochs))
+    DMX_R2 = np.zeros(len(dmx_epochs))
+    for ii, epoch in enumerate(dmx_epochs):
+        DMX_R1[ii] = getattr(model, "DMXR1_{:}".format(epoch)).value
+        DMX_R2[ii] = getattr(model, "DMXR2_{:}".format(epoch)).value
+    ii = np.where((time.mjd > DMX_R1) & (time.mjd < DMX_R2))[0]
+    if len(ii) == 0:
+        raise ValueError(f"Time {time} not in any DMX bins")
+    ii = ii[0]
+    index = int(dmx_epochs[ii])
+    t1 = DMX_R1[ii]
+    t2 = DMX_R2[ii]
+    print(f"{ii} {t1} {t2} {time}")
+    getattr(model, f"DMXR2_{index:04d}").value = time.mjd
+    newindex = model.add_DMX_range(
+        time.mjd,
+        t2,
+        dmx=getattr(model, f"DMX_{index:04d}").quantity,
+        frozen=getattr(model, f"DMX_{index:04d}").frozen,
+    )
+    return index, newindex
+
+
+def split_swx(model, time):
+    """
+    Split an existing SWX bin at the desired time
+
+    Parameters
+    ----------
+    model : pint.models.timing_model.TimingModel
+    time : astropy.time.Time
+
+    Returns
+    -------
+    index : int
+        Index of existing bin that was split
+    newindex : int
+        Index of new bin that was added
+
+    """
+    try:
+        SWX_mapping = model.get_prefix_mapping("SWX_")
+    except ValueError:
+        raise RuntimeError("No SWX values in model!")
+    swx_epochs = [f"{x:04d}" for x in SWX_mapping.keys()]
+    SWX_R1 = np.zeros(len(swx_epochs))
+    SWX_R2 = np.zeros(len(swx_epochs))
+    for ii, epoch in enumerate(swx_epochs):
+        SWX_R1[ii] = getattr(model, "SWXR1_{:}".format(epoch)).value
+        SWX_R2[ii] = getattr(model, "SWXR2_{:}".format(epoch)).value
+    ii = np.where((time.mjd > SWX_R1) & (time.mjd < SWX_R2))[0]
+    if len(ii) == 0:
+        raise ValueError(f"Time {time} not in any SWX bins")
+    ii = ii[0]
+    index = int(swx_epochs[ii])
+    t1 = SWX_R1[ii]
+    t2 = SWX_R2[ii]
+    print(f"{ii} {t1} {t2} {time}")
+    getattr(model, f"SWXR2_{index:04d}").value = time.mjd
+    newindex = model.add_swx_range(
+        time.mjd,
+        t2,
+        swx=getattr(model, f"SWX_{index:04d}").quantity,
+        frozen=getattr(model, f"SWX_{index:04d}").frozen,
+    )
+    return index, newindex
+
+
 def weighted_mean(arrin, weights_in, inputmean=None, calcerr=False, sdev=False):
     """Compute weighted mean of input values
 
@@ -1120,7 +1228,7 @@ def weighted_mean(arrin, weights_in, inputmean=None, calcerr=False, sdev=False):
         wmean = float(inputmean)
     # how should error be calculated?
     if calcerr:
-        werr2 = (weights ** 2 * (arr - wmean) ** 2).sum()
+        werr2 = (weights**2 * (arr - wmean) ** 2).sum()
         werr = np.sqrt(werr2) / wtot
     else:
         werr = 1.0 / np.sqrt(wtot)
@@ -1163,7 +1271,7 @@ def ELL1_check(
         If outstring is True then returns a string summary instead.
 
     """
-    lhs = A1 / const.c * E ** 2.0
+    lhs = A1 / const.c * E**2.0
     rhs = TRES / np.sqrt(NTOA)
     if outstring:
         s = "Checking applicability of ELL1 model -- \n"
@@ -1261,9 +1369,6 @@ def add_dummy_distance(c, distance=1 * u.kpc):
             "No proper motions available for %r: returning coordinates unchanged" % c
         )
         return c
-    if c.obstime is None:
-        log.warning("No obstime available for %r: returning coordinates unchanged" % c)
-        return c
 
     if isinstance(c.frame, coords.builtin_frames.icrs.ICRS):
         if hasattr(c, "pm_ra_cosdec"):
@@ -1340,10 +1445,6 @@ def remove_dummy_distance(c):
             "No proper motions available for %r: returning coordinates unchanged" % c
         )
         return c
-    if c.obstime is None:
-        log.warning("No obstime available for %r: returning coordinates unchanged" % c)
-        return c
-
     if isinstance(c.frame, coords.builtin_frames.icrs.ICRS):
         if hasattr(c, "pm_ra_cosdec"):
 
@@ -1607,3 +1708,202 @@ def list_parameters(class_=None):
                         )
                     results[n]["classes"].append(class_)
         return sorted(results.values(), key=lambda d: d["name"])
+
+
+def colorize(text, fg_color=None, bg_color=None, attribute=None):
+    """Colorizes a string (including unicode strings) for printing on the terminal
+
+    For an example of usage, as well as a demonstration as to what the
+    attributes and colors look like, check out :func:`~pint.utils.print_color_examples`
+
+    Parameters
+    ----------
+    text : string
+        The text to colorize. Can include unicode.
+    fg_color : _type_, optional
+        Foreground color name. The color names (fg or bg) are one of:
+        'black', 'red', 'green', 'yellow', 'blue', 'magenta', 'cyan',
+        or 'white'.
+    bg_color : _type_, optional
+        Background color name, by default None. Same choices as for `fg_color`.
+    attribute : _type_, optional
+        Text attribute, by default None. The text attributes are one of:
+        'normal', 'bold', 'subdued', 'italic', 'underscore', 'blink',
+        'reverse', or 'concealed'.
+
+    Returns
+    -------
+    string
+        The colorized string using the defined text attribute.
+    """
+    COLOR_FORMAT = "\033[%dm\033[%d;%dm%s\033[0m"
+    FOREGROUND = dict(zip(COLOR_NAMES, list(range(30, 38))))
+    BACKGROUND = dict(zip(COLOR_NAMES, list(range(40, 48))))
+    ATTRIBUTE = dict(zip(TEXT_ATTRIBUTES, [0, 1, 2, 3, 4, 5, 7, 8]))
+    fg = FOREGROUND.get(fg_color, 39)
+    bg = BACKGROUND.get(bg_color, 49)
+    att = ATTRIBUTE.get(attribute, 0)
+    return COLOR_FORMAT % (att, bg, fg, text)
+
+
+def print_color_examples():
+    """Print example terminal colors and attributes for/using :func:`~pint.utils.colorize`"""
+    for att in TEXT_ATTRIBUTES:
+        for fg in COLOR_NAMES:
+            for bg in COLOR_NAMES:
+                print(
+                    colorize(f"{fg:>8} {att:<11}", fg, bg_color=bg, attribute=att),
+                    end="",
+                )
+            print("")
+
+
+def group_iterator(items):
+    """An iterator to step over identical items in a :class:`numpy.ndarray`
+
+    Example
+    -------
+    This will step over all of the observatories in the TOAs.
+    For each iteration it gives the observatory name and the indices that correspond to it:
+
+        >>> t = pint.toa.get_TOAs("grouptest.tim")
+        >>> for o, i in group_iterator(t["obs"]):
+        >>>     print(f"{o} {i}")
+
+    """
+    for item in np.unique(items):
+        yield item, np.where(items == item)[0]
+
+
+def compute_hash(filename):
+    """Compute a unique hash of a file.
+
+    This is designed to keep around to detect changes, not to be
+    cryptographically robust. It uses the SHA256 algorithm, which
+    is known to be vulnerable to a length-extension attack.
+
+    Parameter
+    ---------
+    f : str or Path or file-like
+        The source of input. If file-like, it should return ``bytes`` not ``str`` -
+        that is, the file should be opened in binary mode.
+
+    Returns
+    -------
+    bytes
+        A cryptographic hash of the input.
+    """
+    h = hashlib.sha256()
+    with open_or_use(filename, "rb") as f:
+        # Reading in larger chunks saves looping without using
+        # huge amounts of memory; and multiples of the hash
+        # function block size are more efficient.
+        blocks = 128
+        while block := f.read(blocks * h.block_size):
+            h.update(block)
+    return h.digest()
+
+
+def get_conjunction(coord, t0, precision="low", ecl="IERS2010"):
+    """
+    Find first time of Solar conjuction after t0 and approximate elongation at conjunction
+
+    Offers a low-precision version (based on analytic expression of Solar longitude)
+    Or a higher-precision version (based on interpolating :func:`astropy.coordinates.get_sun`)
+
+    Parameters
+    ----------
+    coord : astropy.coordinates.SkyCoord
+    t0 : astropy.time.Time
+    precision : str, optional
+        "low" or "high" precision
+    ecl : str, optional
+        Obliquity for PulsarEcliptic coordinates
+
+    Returns
+    -------
+    astropy.time.Time
+        Time of conjunction
+    astropy.quantity.Quantity
+        Elongation at conjunction
+    """
+
+    assert precision.lower() in ["low", "high"]
+    coord = coord.transform_to(pint.pulsar_ecliptic.PulsarEcliptic(ecl=ecl))
+
+    # low precision version
+    # use analytic form for Sun's ecliptic longitude
+    # and interpolate
+    tt = t0 + np.linspace(0, 365) * u.d
+    # Allen's Astrophysical Quantities
+    # Low precision solar coordinates (27.4.1)
+    # number of days since J2000
+    n = tt.jd - 2451545
+    # mean longitude of Sun, corrected for abberation
+    L = 280.460 * u.deg + 0.9854674 * u.deg * n
+    # Mean anomaly
+    g = 357.528 * u.deg + 0.9856003 * u.deg * n
+    # Ecliptic longitude
+    longitude = L + 1.915 * u.deg * np.sin(g) + 0.20 * u.deg * np.sin(2 * g)
+    dlongitude = longitude - coord.lon
+    dlongitude -= (dlongitude // (360 * u.deg)).max() * 360 * u.deg
+    conjunction = Time(np.interp(0, dlongitude.value, tt.mjd), format="mjd")
+    if precision.lower() == "low":
+        return conjunction, coord.lat
+    # do higher precision
+    # use astropy solar coordinates
+    # start with 10 days on either side of the low precision value
+    tt = conjunction + np.linspace(-10, 10) * u.d
+    csun = coords.get_sun(tt)
+    # this seems to be needed in old astropy
+    csun = coords.SkyCoord(ra=csun.ra, dec=csun.dec)
+    elongation = csun.separation(coord)
+    # get min value and interpolate with a quadratic fit
+    j = np.where(elongation == elongation.min())[0][0]
+    x = tt.mjd[j - 3 : j + 4]
+    y = elongation.value[j - 3 : j + 4]
+    f = np.polyfit(x, y, 2)
+    conjunction = Time(-f[1] / 2 / f[0], format="mjd")
+    csun = coords.get_sun(conjunction)
+    # this seems to be needed in old astropy
+    csun = coords.SkyCoord(ra=csun.ra, dec=csun.dec)
+
+    return conjunction, csun.separation(coord)
+
+
+def divide_times(t, t0, offset=0.5):
+    """
+    Divide input times into years relative to t0
+
+    Years are centered around the requested offset value
+
+    Parameters
+    ----------
+    t : astropy.time.Time
+    t0 : astropy.time.Time
+        Reference time
+    offset : float, optional
+        Offset value for division.  A value of 0.5 divides the results into intervals [-0.5,0.5].
+
+    Returns
+    -------
+    np.ndarray
+        Array of indices for division
+
+
+    Example
+    -------
+    Divide into years around each conjunction
+
+        >>> elongation = astropy.coordinates.get_sun(Time(t.get_mjds(), format="mjd")).separation(m.get_psr_coords())
+        >>> t0 = get_conjunction(m.get_psr_coords(), m.PEPOCH.quantity, precision="high")[0]
+        >>> indices = divide_times(Time(t.get_mjds(), format="mjd"), t0)
+        >>> plt.clf()
+        >>> for i in np.unique(indices):
+                plt.plot(t.get_mjds()[indices == i], elongation[indices == i].value, ".")
+
+    """
+    dt = t - t0
+    values = (dt.to(u.yr).value + offset) // 1
+    indices = np.digitize(values, np.unique(values), right=True)
+    return indices
